{   GNU Pascal Interface to SDL. 
    Copyright (C) 2002,2006 by Eike Lange
    
    This unit is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This unit is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this unit; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Eike Lange, eike.lange@uni-essen.de
    http://www.gnu-pascal.de/~contrib/eike/

    This unit was implemented using version 1.2.8 of libSDL. 
    Some header files and/or routines were not supported:
      Missing:
        SDL_copying.h (nothing to implement)
        SDL_endian.h 
        SDL_loadso.h not Pascal 
        SDL_main.h (noting to implement?)
        SDL_mutex.h (looks intern)
        SDL_name.h (nothing to implement?)
        SDL_opengl.h (not implemented, really missing)
        SDL_quit.h (nothing to implement?)
        SDL_rwops.h
        SDL_syswm.h (system dependant, not for pascal, if you implement, check TSdlSysWMEvent)
        SDL_types.h (partially implemented, mostly not for us)
        SDL_version.h (partially missing)
        SDL_video.h (SDL_VideoInfo, SDL_Overlay, SDL_VideoDriverName, SDL_ListModes, 
          SDL_SetColors, SDL_SetPalette,
          SDL_LoadBMP_RW, SDL_LoadBMP, SDL_SaveBMP_RW, SDL_SaveBMP,
          YUV video surface overlay functions
          OpenGL support functions
          SDL_SoftStretch, SDL_AllocSurface)
}

{
}

{$if __GPC_RELEASE__ < 20050331 }
{$error This unit requires GPC release 20050331 or newer.}
{$endif}



unit Sdl;

interface

uses GPC;

type
  {@section unsorted types, we need them here, because of ordering }
  PByteCard = ^ByteCard;

  PSdlThread = Pointer;
  TSdlThreadFunction = ^function (arg: Pointer): Integer;
  TSdlTimerCallback = ^function (Intervall: Cardinal): Cardinal;
  TSdlNewTimerCallback = ^function (Interval: Cardinal; Param: Pointer): Cardinal;
  PSdlTimerId = Pointer;
  TSdlKey = Integer;
  TSdlMod = Integer;
  TSdlKeysym = record
    ScanCode: ByteCard;
    Sym: TSdlKey;
    Modif: TSdlMod;  {!! Different Name}
    Unicode: ShortCard
  end;
  TSdlRect = record
    x, y: ShortInt;
    w, h: ShortCard
  end;


  {@section types from SDL_audio.h }
  PSdlAudioSpec = ^TSdlAudioSpec;
  TSdlAudioSpecCallback = ^procedure (UserDate: Pointer; var Stream: ByteCard; Len: CInteger);
  TSdlAudioSpec = record
    Freq: CInteger;
    Format: ShortCard;
    Channels, Silence: ByteCard;
    Samples, Padding: ShortCard;
    Size: CCardinal;
    Callback: TSdlAudioSpecCallback;
    UserData: Pointer
  end;

  PSdlAudioCVT = ^TSdlAudioCVT;
  TSdlAudioCVTCallback = ^procedure (Cvt: PSdlAudioCVT; Format: ShortCard);
  TSdlAudioCVT = record
    Needed: CInteger;
    SrcFormat, DstFormat: ShortCard;
    RateIncr: Real;
    Buf: Pointer;
    Len, LenCvt, LenMult: CInteger;
    LenRatio: Real;
    Filters: array [0..9] of TSdlAudioCVTCallback;
    FilterIndex: CInteger
  end;

  TSdlAudioStatus = CInteger;


  {@section types from SDL_cdrom.h }
  PSdlCd = ^TSdlCd;
  CDStatus = CInteger;
  TSdlCdTrack = record
    Id, aType: ByteCard;
    Unused: ShortCard;
    aLength, Offset: CCardinal
  end;
  TSdlCd = record
    Id: CInteger;
    Status: CDStatus;
    NumTracks, CurTrack, CurFrame: CInteger;
    Track: array [0..99] of TSdlCdTrack  {!! check value "0..99" each version }
  end;


  {@section types from SDL_error.h }
  SdlErrorCode = CInteger;


  {@section types from SDL_events.h }
  PSdlEvent = ^TSdlEvent;
  
  TSdlActiveEvent = record
    aType,  {!! Different Name}
    Gain, State: ByteCard
  end;

  TSdlKeyboardEvent = record
    aType,  {!! Different Name}
    Which, State: ByteCard;
    Keysym: TSdlKeysym
  end;
  TSdlMouseMotionEvent = record
    aType,  {!! Different Name}
    Which, State: ByteCard;
    x, y: ShortCard;
    xRel, yRel: ShortInt
  end;
  TSdlMouseButtonEvent = record
    aType,  {!! Different Name}
    Which, Button, State: ByteCard;
    x, y: ShortCard
  end;
  TSdlJoyAxisEvent = record
    aType,  {!! Different Name}
    Which, Axis: ByteCard;
    aValue: ShortInt  {!! Different Name}
  end;
  TSdlJoyBallEvent = record
    aType,  {!! Different Name}
    Which, Ball: ByteCard;
    xRel, yRel: ShortInt
  end;
  TSdlJoyHatEvent = record
    aType,  {!! Different Name}
    Which, Hat,
    aValue: ByteCard  {!! Different Name}
  end;
  TSdlJoyButtonEvent = record
    aType,  {!! Different Name}
    Which, Button, State: ByteCard
  end;
  TSdlResizeEvent = record
    aType: ByteCard;  {!! Different Name}
    w, h: CInteger
  end;
  TSdlExposeEvent = record
    aType: ByteCard  {!! Different Name}
  end;
  TSdlQuitEvent = record
    aType: ByteCard  {!! Different Name}
  end;
  TSdlUserEvent = record
    aType: ByteCard;  {!! Different Name}
    Code: CInteger;
    Data1, Data2: Pointer
  end;
  TSdlSysWMEvent = record
    aType: ByteCard;  {!! Different Name}
    Msg: Pointer      {@@ Should be ^SdlSysWMmsg, which is not implemented }
  end;
  TSdlEvent = record
    case Byte of
       0: (aType:   ByteCard);
       1: (Active:  TSdlActiveEvent);
       2: (Key:     TSdlKeyboardEvent);
       3: (Motion:  TSdlMouseMotionEvent); 
       4: (Button:  TSdlMouseButtonEvent);
       5: (Jaxis:   TSdlJoyAxisEvent);
       6: (Jball:   TSdlJoyBallEvent);
       7: (Jhat:    TSdlJoyHatEvent);
       8: (Jbutton: TSdlJoyButtonEvent);
       9: (Resize:  TSdlResizeEvent);
      10: (Expose:  TSdlExposeEvent);
      11: (Quit:    TSdlQuitEvent);
      12: (User:    TSdlUserEvent);
      13: (SysWm:   TSdlSysWMEvent)
  end;
  TSdlEventAction = CInteger;
  TSdlEventFilter = ^function (const Event: PSdlEvent): Integer;


  {@section types from SDL_joystick.h }
  PSdlJoystick = Pointer;


  {@section types from SDL_mouse.h }
  PSdlCursor = ^TSdlCursor;
  PWMCursor = Pointer;
  TSdlCursorHelper = array [0..MaxVarSize div SizeOf (ByteCard) - 1] of ByteCard;
  TSdlCursor = record
    Area: TSdlRect;
    HotX, HotY: ShortInt;
    Data, Mask: TSdlCursorHelper;
    Save: array [0..1] of TSdlCursorHelper;
    WMCursor: PWMCursor
  end;


  {@section types from SDL_rwops.h }
  PSdlRWops = Pointer;
  

  {@section types from SDL_version }
  PSdlVersion = ^TSdlVersion;
  TSdlVersion = record
    Major, Minor, Patch: ByteCard
  end;


  {@section types from SDL_video.h }
  PSdlRect      = ^TSdlRect;
  PSdlPalette   = ^TSdlPalette;
  PSdlPixelFormat = ^TSdlPixelFormat;
  PSdlSurface   = ^TSdlSurface;
  {^TSdlSurface;}
  PSdlVideoInfo = ^TSdlVideoInfo;
  
  TSdlColor = record
    r, g, b, Unused: ByteCard
  end;
  PColorArray = ^TColorArray;
  TColorArray = array [0.. MaxVarSize div SizeOf (TSdlColor) - 1] of TSdlColor;
  TSdlPalette = record
    NColors: CInteger;
    Colors: PColorArray
  end;
  TSdlPixelFormat = record
    Palette: PSdlPalette;
    BitsPerPixel, BytesPerPixel, RLoss, GLoss, BLoss, ALoss,
      RShift, GShift, BShift, AShift: ByteCard;
    RMask, GMask, BMask, AMask: CCardinal;
    ColorKey: CCardinal;
    Alpha: ByteCard
  end;
  TSdlSurface = record
    Flags: CCardinal;
    Format: PSdlPixelFormat;
    w, h: CInteger;
    Pitch: ShortCard;
    Pixels: Pointer;
    Offset: CInteger;
    HwData: Pointer;  {@@ something different? }
    ClipRect: TSdlRect;
    Unused1: CCardinal;
    Locked: CCardinal;
    Map: Pointer;  {@@ Something Different? }
    FormatVersion: CCardinal;
    RefCount: CInteger
  end;

  { needed for TSdlVideoInfo, TSdlOverlay }
  TCard01 = Cardinal attribute (Size = 1);
  TCard06 = Cardinal attribute (Size = 6);
  TCard16 = Cardinal attribute (Size = 16);
  TCard31 = Cardinal attribute (Size = 31);
  TSdlVideoInfo = packed record
    HwAvailable, WmAvailable: TCard01;
    UnusedBits1: TCard06;
    UnusedBits2: TCard01;
    BlitHw, BlitHwCC, BlitHwA, BlitSw, BlitSwCC, BlitSwA, BlitFill: TCard01;
    UnusedBits3: TCard16;
    VideoMem: Cardinal;
    VFmt: PSdlPixelFormat
  end;
  TSdlOverlay = packed record
    Format: Cardinal;
    w, h, Planes: Integer;
    Pitches, Pixels: Pointer;  {@@ something different!! }
    HwFuncs, HwData: Pointer;  {@@ something different? }
    HwOverlay: TCard01;
    Unused: TCard31
  end;
  TSdlGLattr    = Integer;
  TSdlGrabMode  = Integer;
  TSdlBlit      = ^function (Src: PSdlSurface; SrcRect: PSdlRect;
                    Dest: PSdlSurface; DestRect: PSdlRect): Integer;

{ Please do not assign anything to these identifiers. They should
be treated as constants }
var
  {@section Consts from SDL.h }
  SdlInitTimer:       Integer;  attribute (name = '_p_sdl_init_timer', const); external;
  SdlInitAudio:       Integer;  attribute (name = '_p_sdl_init_audio', const); external;
  SdlInitVideo:       Integer;  attribute (name = '_p_sdl_init_video', const); external;
  SdlInitCdrom:       Integer;  attribute (name = '_p_sdl_init_cdrom', const); external;
  SdlInitJoystick:    Integer;  attribute (name = '_p_sdl_init_joystick', const); external;
  SdlInitNoparachute: Integer;  attribute (name = '_p_sdl_init_noparachute', const); external;
  SdlInitEventThread: Integer;  attribute (name = '_p_sdl_init_eventthread', const); external;
  SdlInitEverything:  Integer;  attribute (name = '_p_sdl_init_everything', const); external;

  {@section Consts from SDL_active.h }
  SdlAppMouseFocus:   Integer;  attribute (name = '_p_sdl_appmousefocus', const); external;
  SdlAppInputFocus:   Integer;  attribute (name = '_p_sdl_appinputfocus', const); external;
  SdlAppActive:       Integer;  attribute (name = '_p_sdl_appactive', const); external;

  {@section Consts from SDL_audio.h }
  AudioU8    : Integer; attribute (name = '_p_AUDIO_U8', const); external;
  AudioS8    : Integer; attribute (name = '_p_AUDIO_S8', const); external;
  AudioU16LSB: Integer; attribute (name = '_p_AUDIO_U16LSB', const); external;
  AudioS16LSB: Integer; attribute (name = '_p_AUDIO_S16LSB', const); external;
  AudioU16MSB: Integer; attribute (name = '_p_AUDIO_U16MSB', const); external;
  AudioS16MSB: Integer; attribute (name = '_p_AUDIO_S16MSB', const); external;
  AudioU16   : Integer; attribute (name = '_p_AUDIO_U16', const); external;
  AudioS16   : Integer; attribute (name = '_p_AUDIO_S16', const); external;
  AudioU16SYS: Integer; attribute (name = '_p_AUDIO_U16SYS', const); external;
  AudioS16SYS: Integer; attribute (name = '_p_AUDIO_S16SYS', const); external;
  SdlMixMaxVolume: Integer; attribute (name = '_p_sdl_MIX_MAXVOLUME', const); external;


  {@section Consts from SDL_byteorder.h }
  SdlLilEndian: Integer; attribute (name = '_p_sdl_LIL_ENDIAN', const); external;
  SdlBigEndian: Integer; attribute (name = '_p_sdl_BIG_ENDIAN', const); external;


  {@section Consts from SDL_cdrom.h }
  SdlMaxTracks:	 Integer; attribute (name = '_p_sdl_MAX_TRACKS', const); external;
  SdlAudioTrack: Integer; attribute (name = '_p_sdl_AUDIO_TRACK', const); external;
  SdlDataTrack:  Integer; attribute (name = '_p_sdl_DATA_TRACK', const); external;
  CdTrayEmpty:   Integer; attribute (name = '_p_cd_TRAYEMPTY', const); external;
  CdStopped:     Integer; attribute (name = '_p_cd_STOPPED', const); external;
  CdPlaying:     Integer; attribute (name = '_p_cd_PLAYING', const); external;
  CdPaused:      Integer; attribute (name = '_p_cd_PAUSED', const); external;
  CdError:       Integer; attribute (name = '_p_cd_ERROR', const); external;
  CdFPS:         Integer; attribute (name = '_p_cd_FPS', const); external;


  {@section Consts from SDL_error.h }
  { Type SdlErrorCode }
  SdlEnomem: Integer; attribute (name = '_p_sdl_ENOMEM', const); external;
  SdlEfRead: Integer; attribute (name = '_p_sdl_EFREAD', const); external;
  SdlEfWrite: Integer; attribute (name = '_p_sdl_EFWRITE', const); external;
  SdlEfSeek: Integer; attribute (name = '_p_sdl_EFSEEK', const); external;
  SdlLastError: Integer; attribute (name = '_p_sdl_LASTERROR', const); external;


  {@section Consts from SDL_events.h }
  SdlNOEVENT:           Integer; attribute (name = '_p_sdl_NOEVENT', const); external;
  SdlActiveEvent:       Integer; attribute (name = '_p_sdl_ACTIVEEVENT', const); external;
  SdlKeyDown:           Integer; attribute (name = '_p_sdl_KEYDOWN', const); external;
  SdlKeyUp:             Integer; attribute (name = '_p_sdl_KEYUP', const); external;
  SdlMouseMotion:       Integer; attribute (name = '_p_sdl_MOUSEMOTION', const); external;
  SdlMouseButtonDown:   Integer; attribute (name = '_p_sdl_MOUSEBUTTONDOWN', const); external;
  SdlMouseButtonUp:     Integer; attribute (name = '_p_sdl_MOUSEBUTTONUP', const); external;
  SdlJoyAxisMotion:     Integer; attribute (name = '_p_sdl_JOYAXISMOTION', const); external;
  SdlJoyBallMotion:     Integer; attribute (name = '_p_sdl_JOYBALLMOTION', const); external;
  SdlJoyHatMotion:      Integer; attribute (name = '_p_sdl_JOYHATMOTION', const); external;
  SdlJoyButtonDown:     Integer; attribute (name = '_p_sdl_JOYBUTTONDOWN', const); external;
  SdlJoyButtonUp:       Integer; attribute (name = '_p_sdl_JOYBUTTONUP', const); external;
  SdlQuitEvent:         Integer; attribute (name = '_p_sdl_QUIT', const); external;
  SdlSysWmEvent:        Integer; attribute (name = '_p_sdl_SYSWMEVENT', const); external;
  SdlEVENT_RESERVEDA:   Integer; attribute (name = '_p_sdl_EVENT_RESERVEDA', const); external;
  SdlEVENT_RESERVEDB:   Integer; attribute (name = '_p_sdl_EVENT_RESERVEDB', const); external;
  SdlVIDEORESIZE:       Integer; attribute (name = '_p_sdl_VIDEORESIZE', const); external;
  SdlVIDEOEXPOSE:       Integer; attribute (name = '_p_sdl_VIDEOEXPOSE', const); external;
  SdlEVENT_RESERVED2:   Integer; attribute (name = '_p_sdl_EVENT_RESERVED2', const); external;
  SdlEVENT_RESERVED3:   Integer; attribute (name = '_p_sdl_EVENT_RESERVED3', const); external;
  SdlEVENT_RESERVED4:   Integer; attribute (name = '_p_sdl_EVENT_RESERVED4', const); external;
  SdlEVENT_RESERVED5:   Integer; attribute (name = '_p_sdl_EVENT_RESERVED5', const); external;
  SdlEVENT_RESERVED6:   Integer; attribute (name = '_p_sdl_EVENT_RESERVED6', const); external;
  SdlEVENT_RESERVED7:   Integer; attribute (name = '_p_sdl_EVENT_RESERVED7', const); external;
  SdlUserEvent:         Integer; attribute (name = '_p_sdl_USEREVENT', const); external;
  SdlNUMEVENTS:         Integer; attribute (name = '_p_sdl_NUMEVENTS', const); external;

  SdlACTIVEEVENTMASK:     Integer; attribute (name = '_p_sdl_ACTIVEEVENTMASK', const); external;
  SdlKEYDOWNMASK:         Integer; attribute (name = '_p_sdl_KEYDOWNMASK', const); external;
  SdlKEYUPMASK:           Integer; attribute (name = '_p_sdl_KEYUPMASK', const); external;
  SdlMOUSEMOTIONMASK:     Integer; attribute (name = '_p_sdl_MOUSEMOTIONMASK', const); external;
  SdlMOUSEBUTTONDOWNMASK: Integer; attribute (name = '_p_sdl_MOUSEBUTTONDOWNMASK', const); external;
  SdlMOUSEBUTTONUPMASK:   Integer; attribute (name = '_p_sdl_MOUSEBUTTONUPMASK', const); external;
  SdlMOUSEEVENTMASK:      Integer; attribute (name = '_p_sdl_MOUSEEVENTMASK', const); external;
  SdlJOYAXISMOTIONMASK:   Integer; attribute (name = '_p_sdl_JOYAXISMOTIONMASK', const); external;
  SdlJOYBALLMOTIONMASK:   Integer; attribute (name = '_p_sdl_JOYBALLMOTIONMASK', const); external;
  SdlJOYHATMOTIONMASK:    Integer; attribute (name = '_p_sdl_JOYHATMOTIONMASK', const); external;
  SdlJOYBUTTONDOWNMASK:   Integer; attribute (name = '_p_sdl_JOYBUTTONDOWNMASK', const); external;
  SdlJOYBUTTONUPMASK:     Integer; attribute (name = '_p_sdl_JOYBUTTONUPMASK', const); external;
  SdlJOYEVENTMASK:        Integer; attribute (name = '_p_sdl_JOYEVENTMASK', const); external;
  SdlVIDEORESIZEMASK:     Integer; attribute (name = '_p_sdl_VIDEORESIZEMASK', const); external;
  SdlVIDEOEXPOSEMASK:     Integer; attribute (name = '_p_sdl_VIDEOEXPOSEMASK', const); external;
  SdlQUITMASK:            Integer; attribute (name = '_p_sdl_QUITMASK', const); external;
  SdlSYSWMEVENTMASK:      Integer; attribute (name = '_p_sdl_SYSWMEVENTMASK', const); external;
  SdlALLEVENTS:           Integer; attribute (name = '_p_sdl_ALLEVENTS', const); external;
  SdlQuery:       Integer; attribute (name = '_p_sdl_query', const); external;
  SdlIgnore:      Integer; attribute (name = '_p_sdl_ignore', const); external;
  SdlDisable:     Integer; attribute (name = '_p_sdl_disable', const); external;
  SdlEnable:      Integer; attribute (name = '_p_sdl_enable', const); external;

  { TSdlEventAction }
  SdlAddEvent:    Integer;  attribute (name = '_p_sdl_addevent', const); external;
  SdlPeekEvent:   Integer;  attribute (name = '_p_sdl_peekevent', const); external;
  SdlGetEvent:    Integer;  attribute (name = '_p_sdl_getevent', const); external;


  {@section Consts from SDL_joystick.h }
  SdlHatCentered:  Integer; attribute (name = '_p_sdl_HAT_CENTERED', const); external;
  SdlHatUp:        Integer; attribute (name = '_p_sdl_HAT_UP', const); external;
  SdlHatRight:     Integer; attribute (name = '_p_sdl_HAT_RIGHT', const); external;
  SdlHatDown:      Integer; attribute (name = '_p_sdl_HAT_DOWN', const); external;
  SdlHatLeft:      Integer; attribute (name = '_p_sdl_HAT_LEFT', const); external;
  SdlHatRightup:   Integer; attribute (name = '_p_sdl_HAT_RIGHTUP', const); external;
  SdlHatRightdown: Integer; attribute (name = '_p_sdl_HAT_RIGHTDOWN', const); external;
  SdlHatLeftup:    Integer; attribute (name = '_p_sdl_HAT_LEFTUP', const); external;
  SdlHatLeftdown:  Integer; attribute (name = '_p_sdl_HAT_LEFTDOWN', const); external;


  {@section Consts from SDL_keyboard.h }
  SdlAllHotkeys:            Integer; attribute (name = '_p_sdl_all_hotkeys', const); external;
  SdlDefaultRepeatDelay:    Integer; attribute (name = '_p_sdl_default_repeat_delay', const); external;
  SdlDefaultRepeatInterval: Integer; attribute (name = '_p_sdl_default_repeat_interval', const); external;


  {@section Const from SDL_keysym.h }
  { SDLKey consts }
  SdlkUNKNOWN:      Integer; attribute (name = '_p_sdlk_UNKNOWN', const); external;
  SdlkFIRST:        Integer; attribute (name = '_p_sdlk_FIRST', const); external;
  SdlkBACKSPACE:    Integer; attribute (name = '_p_sdlk_BACKSPACE', const); external;
  SdlkTAB:          Integer; attribute (name = '_p_sdlk_TAB', const); external;
  SdlkCLEAR:        Integer; attribute (name = '_p_sdlk_CLEAR', const); external;
  SdlkRETURN:       Integer; attribute (name = '_p_sdlk_RETURN', const); external;
  SdlkPAUSE:        Integer; attribute (name = '_p_sdlk_PAUSE', const); external;
  SdlkESCAPE:       Integer; attribute (name = '_p_sdlk_ESCAPE', const); external;
  SdlkSPACE:        Integer; attribute (name = '_p_sdlk_SPACE', const); external;
  SdlkEXCLAIM:      Integer; attribute (name = '_p_sdlk_EXCLAIM', const); external;
  SdlkQUOTEDBL:     Integer; attribute (name = '_p_sdlk_QUOTEDBL', const); external;
  SdlkHASH:         Integer; attribute (name = '_p_sdlk_HASH', const); external;
  SdlkDOLLAR:       Integer; attribute (name = '_p_sdlk_DOLLAR', const); external;
  SdlkAMPERSAND:    Integer; attribute (name = '_p_sdlk_AMPERSAND', const); external;
  SdlkQUOTE:        Integer; attribute (name = '_p_sdlk_QUOTE', const); external;
  SdlkLEFTPAREN:    Integer; attribute (name = '_p_sdlk_LEFTPAREN', const); external;
  SdlkRIGHTPAREN:   Integer; attribute (name = '_p_sdlk_RIGHTPAREN', const); external;
  SdlkASTERISK:     Integer; attribute (name = '_p_sdlk_ASTERISK', const); external;
  SdlkPLUS:         Integer; attribute (name = '_p_sdlk_PLUS', const); external;
  SdlkCOMMA:        Integer; attribute (name = '_p_sdlk_COMMA', const); external;
  SdlkMINUS:        Integer; attribute (name = '_p_sdlk_MINUS', const); external;
  SdlkPERIOD:       Integer; attribute (name = '_p_sdlk_PERIOD', const); external;
  SdlkSLASH:        Integer; attribute (name = '_p_sdlk_SLASH', const); external;
  Sdlk0:            Integer; attribute (name = '_p_sdlk_0', const); external;
  Sdlk1:            Integer; attribute (name = '_p_sdlk_1', const); external;
  Sdlk2:            Integer; attribute (name = '_p_sdlk_2', const); external;
  Sdlk3:            Integer; attribute (name = '_p_sdlk_3', const); external;
  Sdlk4:            Integer; attribute (name = '_p_sdlk_4', const); external;
  Sdlk5:            Integer; attribute (name = '_p_sdlk_5', const); external;
  Sdlk6:            Integer; attribute (name = '_p_sdlk_6', const); external;
  Sdlk7:            Integer; attribute (name = '_p_sdlk_7', const); external;
  Sdlk8:            Integer; attribute (name = '_p_sdlk_8', const); external;
  Sdlk9:            Integer; attribute (name = '_p_sdlk_9', const); external;
  SdlkCOLON:        Integer; attribute (name = '_p_sdlk_COLON', const); external;
  SdlkSEMICOLON:    Integer; attribute (name = '_p_sdlk_SEMICOLON', const); external;
  SdlkLESS:         Integer; attribute (name = '_p_sdlk_LESS', const); external;
  SdlkEQUALS:       Integer; attribute (name = '_p_sdlk_EQUALS', const); external;
  SdlkGREATER:      Integer; attribute (name = '_p_sdlk_GREATER', const); external;
  SdlkQUESTION:     Integer; attribute (name = '_p_sdlk_QUESTION', const); external;
  SdlkAT:           Integer; attribute (name = '_p_sdlk_AT', const); external;
  SdlkLEFTBRACKET:  Integer; attribute (name = '_p_sdlk_LEFTBRACKET', const); external;
  SdlkBACKSLASH:    Integer; attribute (name = '_p_sdlk_BACKSLASH', const); external;
  SdlkRIGHTBRACKET: Integer; attribute (name = '_p_sdlk_RIGHTBRACKET', const); external;
  SdlkCARET:        Integer; attribute (name = '_p_sdlk_CARET', const); external;
  SdlkUNDERSCORE:   Integer; attribute (name = '_p_sdlk_UNDERSCORE', const); external;
  SdlkBACKQUOTE:    Integer; attribute (name = '_p_sdlk_BACKQUOTE', const); external;
  Sdlka:            Integer; attribute (name = '_p_sdlk_a', const); external;
  Sdlkb:            Integer; attribute (name = '_p_sdlk_b', const); external;
  Sdlkc:            Integer; attribute (name = '_p_sdlk_c', const); external;
  Sdlkd:            Integer; attribute (name = '_p_sdlk_d', const); external;
  Sdlke:            Integer; attribute (name = '_p_sdlk_e', const); external;
  Sdlkf:            Integer; attribute (name = '_p_sdlk_f', const); external;
  Sdlkg:            Integer; attribute (name = '_p_sdlk_g', const); external;
  Sdlkh:            Integer; attribute (name = '_p_sdlk_h', const); external;
  Sdlki:            Integer; attribute (name = '_p_sdlk_i', const); external;
  Sdlkj:            Integer; attribute (name = '_p_sdlk_j', const); external;
  Sdlkk:            Integer; attribute (name = '_p_sdlk_k', const); external;
  Sdlkl:            Integer; attribute (name = '_p_sdlk_l', const); external;
  Sdlkm:            Integer; attribute (name = '_p_sdlk_m', const); external;
  Sdlkn:            Integer; attribute (name = '_p_sdlk_n', const); external;
  Sdlko:            Integer; attribute (name = '_p_sdlk_o', const); external;
  Sdlkp:            Integer; attribute (name = '_p_sdlk_p', const); external;
  Sdlkq:            Integer; attribute (name = '_p_sdlk_q', const); external;
  Sdlkr:            Integer; attribute (name = '_p_sdlk_r', const); external;
  Sdlks:            Integer; attribute (name = '_p_sdlk_s', const); external;
  Sdlkt:            Integer; attribute (name = '_p_sdlk_t', const); external;
  Sdlku:            Integer; attribute (name = '_p_sdlk_u', const); external;
  Sdlkv:            Integer; attribute (name = '_p_sdlk_v', const); external;
  Sdlkw:            Integer; attribute (name = '_p_sdlk_w', const); external;
  Sdlkx:            Integer; attribute (name = '_p_sdlk_x', const); external;
  Sdlky:            Integer; attribute (name = '_p_sdlk_y', const); external;
  Sdlkz:            Integer; attribute (name = '_p_sdlk_z', const); external;
  SdlkDELETE:       Integer; attribute (name = '_p_sdlk_DELETE', const); external;
  SdlkWORLD0:       Integer; attribute (name = '_p_sdlk_WORLD_0', const); external;
  SdlkWORLD1:       Integer; attribute (name = '_p_sdlk_WORLD_1', const); external;
  SdlkWORLD2:       Integer; attribute (name = '_p_sdlk_WORLD_2', const); external;
  SdlkWORLD3:       Integer; attribute (name = '_p_sdlk_WORLD_3', const); external;
  SdlkWORLD4:       Integer; attribute (name = '_p_sdlk_WORLD_4', const); external;
  SdlkWORLD5:       Integer; attribute (name = '_p_sdlk_WORLD_5', const); external;
  SdlkWORLD6:       Integer; attribute (name = '_p_sdlk_WORLD_6', const); external;
  SdlkWORLD7:       Integer; attribute (name = '_p_sdlk_WORLD_7', const); external;
  SdlkWORLD8:       Integer; attribute (name = '_p_sdlk_WORLD_8', const); external;
  SdlkWORLD9:       Integer; attribute (name = '_p_sdlk_WORLD_9', const); external;
  SdlkWORLD10:      Integer; attribute (name = '_p_sdlk_WORLD_10', const); external;
  SdlkWORLD11:      Integer; attribute (name = '_p_sdlk_WORLD_11', const); external;
  SdlkWORLD12:      Integer; attribute (name = '_p_sdlk_WORLD_12', const); external;
  SdlkWORLD13:      Integer; attribute (name = '_p_sdlk_WORLD_13', const); external;
  SdlkWORLD14:      Integer; attribute (name = '_p_sdlk_WORLD_14', const); external;
  SdlkWORLD15:      Integer; attribute (name = '_p_sdlk_WORLD_15', const); external;
  SdlkWORLD16:      Integer; attribute (name = '_p_sdlk_WORLD_16', const); external;
  SdlkWORLD17:      Integer; attribute (name = '_p_sdlk_WORLD_17', const); external;
  SdlkWORLD18:      Integer; attribute (name = '_p_sdlk_WORLD_18', const); external;
  SdlkWORLD19:      Integer; attribute (name = '_p_sdlk_WORLD_19', const); external;
  SdlkWORLD20:      Integer; attribute (name = '_p_sdlk_WORLD_20', const); external;
  SdlkWORLD21:      Integer; attribute (name = '_p_sdlk_WORLD_21', const); external;
  SdlkWORLD22:      Integer; attribute (name = '_p_sdlk_WORLD_22', const); external;
  SdlkWORLD23:      Integer; attribute (name = '_p_sdlk_WORLD_23', const); external;
  SdlkWORLD24:      Integer; attribute (name = '_p_sdlk_WORLD_24', const); external;
  SdlkWORLD25:      Integer; attribute (name = '_p_sdlk_WORLD_25', const); external;
  SdlkWORLD26:      Integer; attribute (name = '_p_sdlk_WORLD_26', const); external;
  SdlkWORLD27:      Integer; attribute (name = '_p_sdlk_WORLD_27', const); external;
  SdlkWORLD28:      Integer; attribute (name = '_p_sdlk_WORLD_28', const); external;
  SdlkWORLD29:      Integer; attribute (name = '_p_sdlk_WORLD_29', const); external;
  SdlkWORLD30:      Integer; attribute (name = '_p_sdlk_WORLD_30', const); external;
  SdlkWORLD31:      Integer; attribute (name = '_p_sdlk_WORLD_31', const); external;
  SdlkWORLD32:      Integer; attribute (name = '_p_sdlk_WORLD_32', const); external;
  SdlkWORLD33:      Integer; attribute (name = '_p_sdlk_WORLD_33', const); external;
  SdlkWORLD34:      Integer; attribute (name = '_p_sdlk_WORLD_34', const); external;
  SdlkWORLD35:      Integer; attribute (name = '_p_sdlk_WORLD_35', const); external;
  SdlkWORLD36:      Integer; attribute (name = '_p_sdlk_WORLD_36', const); external;
  SdlkWORLD37:      Integer; attribute (name = '_p_sdlk_WORLD_37', const); external;
  SdlkWORLD38:      Integer; attribute (name = '_p_sdlk_WORLD_38', const); external;
  SdlkWORLD39:      Integer; attribute (name = '_p_sdlk_WORLD_39', const); external;
  SdlkWORLD40:      Integer; attribute (name = '_p_sdlk_WORLD_40', const); external;
  SdlkWORLD41:      Integer; attribute (name = '_p_sdlk_WORLD_41', const); external;
  SdlkWORLD42:      Integer; attribute (name = '_p_sdlk_WORLD_42', const); external;
  SdlkWORLD43:      Integer; attribute (name = '_p_sdlk_WORLD_43', const); external;
  SdlkWORLD44:      Integer; attribute (name = '_p_sdlk_WORLD_44', const); external;
  SdlkWORLD45:      Integer; attribute (name = '_p_sdlk_WORLD_45', const); external;
  SdlkWORLD46:      Integer; attribute (name = '_p_sdlk_WORLD_46', const); external;
  SdlkWORLD47:      Integer; attribute (name = '_p_sdlk_WORLD_47', const); external;
  SdlkWORLD48:      Integer; attribute (name = '_p_sdlk_WORLD_48', const); external;
  SdlkWORLD49:      Integer; attribute (name = '_p_sdlk_WORLD_49', const); external;
  SdlkWORLD50:      Integer; attribute (name = '_p_sdlk_WORLD_50', const); external;
  SdlkWORLD51:      Integer; attribute (name = '_p_sdlk_WORLD_51', const); external;
  SdlkWORLD52:      Integer; attribute (name = '_p_sdlk_WORLD_52', const); external;
  SdlkWORLD53:      Integer; attribute (name = '_p_sdlk_WORLD_53', const); external;
  SdlkWORLD54:      Integer; attribute (name = '_p_sdlk_WORLD_54', const); external;
  SdlkWORLD55:      Integer; attribute (name = '_p_sdlk_WORLD_55', const); external;
  SdlkWORLD56:      Integer; attribute (name = '_p_sdlk_WORLD_56', const); external;
  SdlkWORLD57:      Integer; attribute (name = '_p_sdlk_WORLD_57', const); external;
  SdlkWORLD58:      Integer; attribute (name = '_p_sdlk_WORLD_58', const); external;
  SdlkWORLD59:      Integer; attribute (name = '_p_sdlk_WORLD_59', const); external;
  SdlkWORLD60:      Integer; attribute (name = '_p_sdlk_WORLD_60', const); external;
  SdlkWORLD61:      Integer; attribute (name = '_p_sdlk_WORLD_61', const); external;
  SdlkWORLD62:      Integer; attribute (name = '_p_sdlk_WORLD_62', const); external;
  SdlkWORLD63:      Integer; attribute (name = '_p_sdlk_WORLD_63', const); external;
  SdlkWORLD64:      Integer; attribute (name = '_p_sdlk_WORLD_64', const); external;
  SdlkWORLD65:      Integer; attribute (name = '_p_sdlk_WORLD_65', const); external;
  SdlkWORLD66:      Integer; attribute (name = '_p_sdlk_WORLD_66', const); external;
  SdlkWORLD67:      Integer; attribute (name = '_p_sdlk_WORLD_67', const); external;
  SdlkWORLD68:      Integer; attribute (name = '_p_sdlk_WORLD_68', const); external;
  SdlkWORLD69:      Integer; attribute (name = '_p_sdlk_WORLD_69', const); external;
  SdlkWORLD70:      Integer; attribute (name = '_p_sdlk_WORLD_70', const); external;
  SdlkWORLD71:      Integer; attribute (name = '_p_sdlk_WORLD_71', const); external;
  SdlkWORLD72:      Integer; attribute (name = '_p_sdlk_WORLD_72', const); external;
  SdlkWORLD73:      Integer; attribute (name = '_p_sdlk_WORLD_73', const); external;
  SdlkWORLD74:      Integer; attribute (name = '_p_sdlk_WORLD_74', const); external;
  SdlkWORLD75:      Integer; attribute (name = '_p_sdlk_WORLD_75', const); external;
  SdlkWORLD76:      Integer; attribute (name = '_p_sdlk_WORLD_76', const); external;
  SdlkWORLD77:      Integer; attribute (name = '_p_sdlk_WORLD_77', const); external;
  SdlkWORLD78:      Integer; attribute (name = '_p_sdlk_WORLD_78', const); external;
  SdlkWORLD79:      Integer; attribute (name = '_p_sdlk_WORLD_79', const); external;
  SdlkWORLD80:      Integer; attribute (name = '_p_sdlk_WORLD_80', const); external;
  SdlkWORLD81:      Integer; attribute (name = '_p_sdlk_WORLD_81', const); external;
  SdlkWORLD82:      Integer; attribute (name = '_p_sdlk_WORLD_82', const); external;
  SdlkWORLD83:      Integer; attribute (name = '_p_sdlk_WORLD_83', const); external;
  SdlkWORLD84:      Integer; attribute (name = '_p_sdlk_WORLD_84', const); external;
  SdlkWORLD85:      Integer; attribute (name = '_p_sdlk_WORLD_85', const); external;
  SdlkWORLD86:      Integer; attribute (name = '_p_sdlk_WORLD_86', const); external;
  SdlkWORLD87:      Integer; attribute (name = '_p_sdlk_WORLD_87', const); external;
  SdlkWORLD88:      Integer; attribute (name = '_p_sdlk_WORLD_88', const); external;
  SdlkWORLD89:      Integer; attribute (name = '_p_sdlk_WORLD_89', const); external;
  SdlkWORLD90:      Integer; attribute (name = '_p_sdlk_WORLD_90', const); external;
  SdlkWORLD91:      Integer; attribute (name = '_p_sdlk_WORLD_91', const); external;
  SdlkWORLD92:      Integer; attribute (name = '_p_sdlk_WORLD_92', const); external;
  SdlkWORLD93:      Integer; attribute (name = '_p_sdlk_WORLD_93', const); external;
  SdlkWORLD94:      Integer; attribute (name = '_p_sdlk_WORLD_94', const); external;
  SdlkWORLD95:      Integer; attribute (name = '_p_sdlk_WORLD_95', const); external;
  SdlkKP0:          Integer; attribute (name = '_p_sdlk_KP0', const); external;
  SdlkKP1:          Integer; attribute (name = '_p_sdlk_KP1', const); external;
  SdlkKP2:          Integer; attribute (name = '_p_sdlk_KP2', const); external;
  SdlkKP3:          Integer; attribute (name = '_p_sdlk_KP3', const); external;
  SdlkKP4:          Integer; attribute (name = '_p_sdlk_KP4', const); external;
  SdlkKP5:          Integer; attribute (name = '_p_sdlk_KP5', const); external;
  SdlkKP6:          Integer; attribute (name = '_p_sdlk_KP6', const); external;
  SdlkKP7:          Integer; attribute (name = '_p_sdlk_KP7', const); external;
  SdlkKP8:          Integer; attribute (name = '_p_sdlk_KP8', const); external;
  SdlkKP9:          Integer; attribute (name = '_p_sdlk_KP9', const); external;
  SdlkKPPERIOD:     Integer; attribute (name = '_p_sdlk_KP_PERIOD', const); external;
  SdlkKPDIVIDE:     Integer; attribute (name = '_p_sdlk_KP_DIVIDE', const); external;
  SdlkKPMULTIPL:    Integer; attribute (name = '_p_sdlk_KP_MULTIPLY', const); external;
  SdlkKPMINUS:      Integer; attribute (name = '_p_sdlk_KP_MINUS', const); external;
  SdlkKPPLUS:       Integer; attribute (name = '_p_sdlk_KP_PLUS', const); external;
  SdlkKPENTER:      Integer; attribute (name = '_p_sdlk_KP_ENTER', const); external;
  SdlkKPEQUALS:     Integer; attribute (name = '_p_sdlk_KP_EQUALS', const); external;
  SdlkUP:           Integer; attribute (name = '_p_sdlk_UP', const); external;
  SdlkDOWN:         Integer; attribute (name = '_p_sdlk_DOWN', const); external;
  SdlkRIGHT:        Integer; attribute (name = '_p_sdlk_RIGHT', const); external;
  SdlkLEFT:         Integer; attribute (name = '_p_sdlk_LEFT', const); external;
  SdlkINSERT:       Integer; attribute (name = '_p_sdlk_INSERT', const); external;
  SdlkHOME:         Integer; attribute (name = '_p_sdlk_HOME', const); external;
  SdlkEND:          Integer; attribute (name = '_p_sdlk_END', const); external;
  SdlkPAGEUP:       Integer; attribute (name = '_p_sdlk_PAGEUP', const); external;
  SdlkPAGEDOWN:     Integer; attribute (name = '_p_sdlk_PAGEDOWN', const); external;
  SdlkF1:           Integer; attribute (name = '_p_sdlk_F1', const); external;
  SdlkF2:           Integer; attribute (name = '_p_sdlk_F2', const); external;
  SdlkF3:           Integer; attribute (name = '_p_sdlk_F3', const); external;
  SdlkF4:           Integer; attribute (name = '_p_sdlk_F4', const); external;
  SdlkF5:           Integer; attribute (name = '_p_sdlk_F5', const); external;
  SdlkF6:           Integer; attribute (name = '_p_sdlk_F6', const); external;
  SdlkF7:           Integer; attribute (name = '_p_sdlk_F7', const); external;
  SdlkF8:           Integer; attribute (name = '_p_sdlk_F8', const); external;
  SdlkF9:           Integer; attribute (name = '_p_sdlk_F9', const); external;
  SdlkF10:          Integer; attribute (name = '_p_sdlk_F10', const); external;
  SdlkF11:          Integer; attribute (name = '_p_sdlk_F11', const); external;
  SdlkF12:          Integer; attribute (name = '_p_sdlk_F12', const); external;
  SdlkF13:          Integer; attribute (name = '_p_sdlk_F13', const); external;
  SdlkF14:          Integer; attribute (name = '_p_sdlk_F14', const); external;
  SdlkF15:          Integer; attribute (name = '_p_sdlk_F15', const); external;
  SdlkNUMLOCK:      Integer; attribute (name = '_p_sdlk_NUMLOCK', const); external;
  SdlkCAPSLOCK:     Integer; attribute (name = '_p_sdlk_CAPSLOCK', const); external;
  SdlkSCROLLOCK:    Integer; attribute (name = '_p_sdlk_SCROLLOCK', const); external;
  SdlkRSHIFT:       Integer; attribute (name = '_p_sdlk_RSHIFT', const); external;
  SdlkLSHIFT:       Integer; attribute (name = '_p_sdlk_LSHIFT', const); external;
  SdlkRCTRL:        Integer; attribute (name = '_p_sdlk_RCTRL', const); external;
  SdlkLCTRL:        Integer; attribute (name = '_p_sdlk_LCTRL', const); external;
  SdlkRALT:         Integer; attribute (name = '_p_sdlk_RALT', const); external;
  SdlkLALT:         Integer; attribute (name = '_p_sdlk_LALT', const); external;
  SdlkRMETA:        Integer; attribute (name = '_p_sdlk_RMETA', const); external;
  SdlkLMETA:        Integer; attribute (name = '_p_sdlk_LMETA', const); external;
  SdlkLSUPER:       Integer; attribute (name = '_p_sdlk_LSUPER', const); external;
  SdlkRSUPER:       Integer; attribute (name = '_p_sdlk_RSUPER', const); external;
  SdlkMODE:         Integer; attribute (name = '_p_sdlk_MODE', const); external;
  SdlkCOMPOSE:      Integer; attribute (name = '_p_sdlk_COMPOSE', const); external;
  SdlkHELP:         Integer; attribute (name = '_p_sdlk_HELP', const); external;
  SdlkPRINT:        Integer; attribute (name = '_p_sdlk_PRINT', const); external;
  SdlkSYSREQ:       Integer; attribute (name = '_p_sdlk_SYSREQ', const); external;
  SdlkBREAK:        Integer; attribute (name = '_p_sdlk_BREAK', const); external;
  SdlkMENU:         Integer; attribute (name = '_p_sdlk_MENU', const); external;
  SdlkPOWER:        Integer; attribute (name = '_p_sdlk_POWER', const); external;
  SdlkEURO:         Integer; attribute (name = '_p_sdlk_EURO', const); external;
  SdlkUNDO:         Integer; attribute (name = '_p_sdlk_UNDO', const); external;
  SdlkLAST:         Integer; attribute (name = '_p_sdlk_LAST', const); external;

  { SDLMod }
  KModNONE:       Integer; attribute (name = '_p_kmod_NONE', const); external;
  KModLSHIFT:     Integer; attribute (name = '_p_kmod_LSHIFT', const); external;
  KModRSHIFT:     Integer; attribute (name = '_p_kmod_RSHIFT', const); external;
  KModLCTRL:      Integer; attribute (name = '_p_kmod_LCTRL', const); external;
  KModRCTRL:      Integer; attribute (name = '_p_kmod_RCTRL', const); external;
  KModLALT:       Integer; attribute (name = '_p_kmod_LALT', const); external;
  KModRALT:       Integer; attribute (name = '_p_kmod_RALT', const); external;
  KModLMETA:      Integer; attribute (name = '_p_kmod_LMETA', const); external;
  KModRMETA:      Integer; attribute (name = '_p_kmod_RMETA', const); external;
  KModNUM:        Integer; attribute (name = '_p_kmod_NUM', const); external;
  KModCAPS:       Integer; attribute (name = '_p_kmod_CAPS', const); external;
  KModMODE:       Integer; attribute (name = '_p_kmod_MODE', const); external;
  KModRESERVED:   Integer; attribute (name = '_p_kmod_RESERVED', const); external;
  KModCTRL:       Integer; attribute (name = '_p_kmod_CTRL', const); external;
  KModSHIFT:      Integer; attribute (name = '_p_kmod_SHIFT', const); external;
  KModALT:        Integer; attribute (name = '_p_kmod_ALT', const); external;
  KModMETA:       Integer; attribute (name = '_p_kmod_META', const); external;


  {@section Consts from SDL_mouse.h }
  SdlButtonLeft:    Integer;    attribute (name = '_p_sdl_button_left', const); external;
  SdlButtonMiddle:  Integer;    attribute (name = '_p_sdl_button_middle', const); external;
  SdlButtonRight:   Integer;    attribute (name = '_p_sdl_button_right', const); external;
  SdlButtonLMask:   Integer;    attribute (name = '_p_sdl_button_lmask', const); external;
  SdlButtonMMask:   Integer;    attribute (name = '_p_sdl_button_mmask', const); external;
  SdlButtonRMask:   Integer;    attribute (name = '_p_sdl_button_rmask', const); external;


  {@section Consts from SDL_timer.h }
  SdlTimeSlice:     Integer;  attribute (name = '_p_sdl_timeslice', const); external;
  TimerResolution:  Integer;  attribute (name = '_p_timer_resolution', const); external;

  {@section Consts from SDL_types.h }
  SdlPressed:       Integer;    attribute (name = '_p_sdl_pressed', const); external;
  SdlReleased:      Integer;    attribute (name = '_p_sdl_released', const); external;

  {@section Consts from SDL_version.h }
  SdlMajorVersion:  Integer;    attribute (name = '_p_sdl_major_version', const); external;
  SdlMinorVersion:  Integer;    attribute (name = '_p_sdl_minor_version', const); external;
  SdlPatchlevel:    Integer;    attribute (name = '_p_sdl_patchlevel', const); external;

  {@section Const from SDL_video.h }
  { Transparency definitions }
  SdlALPHAOPAQUE:       Integer; attribute (name = '_p_sdl_ALPHA_OPAQUE', const); external;
  SdlALPHATRANSPARENT:  Integer; attribute (name = '_p_sdl_ALPHA_TRANSPARENT', const); external;

  { flags for the SdlSurface 
    Available for SdlCreateRGBSurface or SdlSetVideoMode }
  SdlSWSURFACE:         CCardinal; attribute (name = '_p_sdl_SWSURFACE',const); external;
  SdlHWSURFACE:         CCardinal; attribute (name = '_p_sdl_HWSURFACE',const); external;
  SdlASYNCBLIT:         CCardinal; attribute (name = '_p_sdl_ASYNCBLIT',const); external;
  SdlANYFORMAT:         CCardinal; attribute (name = '_p_sdl_ANYFORMAT',const); external;
  SdlHWPALETTE:         CCardinal; attribute (name = '_p_sdl_HWPALETTE',const); external;
  SdlDOUBLEBUF:         CCardinal; attribute (name = '_p_sdl_DOUBLEBUF',const); external;
  SdlFULLSCREEN:        CCardinal; attribute (name = '_p_sdl_FULLSCREEN',const); external;
  SdlOPENGL:            CCardinal; attribute (name = '_p_sdl_OPENGL',const); external;
  SdlOPENGLBLIT:        CCardinal; attribute (name = '_p_sdl_OPENGLBLIT',const); external;
  SdlRESIZABLE:         CCardinal; attribute (name = '_p_sdl_RESIZABLE',const); external;
  SdlNOFRAME:           CCardinal; attribute (name = '_p_sdl_NOFRAME',const); external;
  SdlHWACCEL:           CCardinal; attribute (name = '_p_sdl_HWACCEL',const); external;
  SdlSRCCOLORKEY:       CCardinal; attribute (name = '_p_sdl_SRCCOLORKEY',const); external;
  SdlRLEACCELOK:        CCardinal; attribute (name = '_p_sdl_RLEACCELOK',const); external;
  SdlRLEACCEL:          CCardinal; attribute (name = '_p_sdl_RLEACCEL',const); external;
  SdlSRCALPHA:          CCardinal; attribute (name = '_p_sdl_SRCALPHA',const); external;
  SdlPREALLOC:          CCardinal; attribute (name = '_p_sdl_PREALLOC',const); external;

  { The most common video overlay formats }
  SdlYV12OVERLAY:       Integer; attribute (name = '_p_sdl_YV12_OVERLAY', const); external;
  SdlIYUVOVERLAY:       Integer; attribute (name = '_p_sdl_IYUV_OVERLAY', const); external;
  SdlYUY2OVERLAY:       Integer; attribute (name = '_p_sdl_YUY2_OVERLAY', const); external;
  SdlUYVYOVERLAY:       Integer; attribute (name = '_p_sdl_UYVY_OVERLAY', const); external;
  SdlYVYUOVERLAY:       Integer; attribute (name = '_p_sdl_YVYU_OVERLAY', const); external;

  { Flags for SdlPalette }
  SdlLOGPAL:            Integer; attribute (name = '_p_sdl_LOGPAL', const); external;
  SdlPHYSPAL:           Integer; attribute (name = '_p_sdl_PHYSPAL', const); external;

  { TSdlGlAttr }
  SdlGlRedSize:         Integer; attribute (name = '_p_sdl_gl_RED_SIZE', const); external;
  SdlGlGreenSize:       Integer; attribute (name = '_p_sdl_gl_GREEN_SIZE', const); external;
  SdlGlBlueSize:        Integer; attribute (name = '_p_sdl_gl_BLUE_SIZE', const); external;
  SdlGlALPHASize:       Integer; attribute (name = '_p_sdl_gl_ALPHA_SIZE', const); external;
  SdlGlBUFFERSize:      Integer; attribute (name = '_p_sdl_gl_BUFFER_SIZE', const); external;
  SdlGlDOUBLEBuffer:    Integer; attribute (name = '_p_sdl_gl_DOUBLEBUFFER', const); external;
  SdlGlDEPTHSize:       Integer; attribute (name = '_p_sdl_gl_DEPTH_SIZE', const); external;
  SdlGlSTENCILSize:     Integer; attribute (name = '_p_sdl_gl_STENCIL_SIZE', const); external;
  SdlGlACCUMRedSize:    Integer; attribute (name = '_p_sdl_gl_ACCUM_RED_SIZE', const); external;
  SdlGlACCUMGreenSize:  Integer; attribute (name = '_p_sdl_gl_ACCUM_GREEN_SIZE', const); external;
  SdlGlACCUMBlueSize:   Integer; attribute (name = '_p_sdl_gl_ACCUM_BLUE_SIZE', const); external;
  SdlGlACCUMAlphaSize:  Integer; attribute (name = '_p_sdl_gl_ACCUM_ALPHA_SIZE', const); external;

  { TSdlGrabMode }
  SdlGrabQuery:       Integer; attribute (name = '_p_sdl_grab_query', const); external;
  SdlGrabOff:         Integer; attribute (name = '_p_sdl_grab_off', const); external;
  SdlGrabOn:          Integer; attribute (name = '_p_sdl_grab_on', const); external;
  SdlGrabFullscreen:  Integer; attribute (name = '_p_sdl_grab_fullscreen', const); external;



{@section Routines from SDL.h }
function SdlInit (Flags: Cardinal): Integer; attribute (name = 'SDL_Init'); external;
function SdlInitSubsystem (Flags: Cardinal): Integer; attribute (name = 'SDL_InitSubSystem'); external;
procedure SdlQuitSubSystem (Flags: Cardinal); attribute (name = 'SDL_QuitSubSystem'); external;
function SdlWasInit (Flags: Cardinal): Cardinal; attribute (name = 'SDL_WasInit'); external;
procedure SdlQuit; attribute (name = 'SDL_Quit'); external;


{@section Routines from SDL_active.h }
function SdlGetAppState: ByteCard; attribute (name = 'SDL_GetAppState'); external;


{@section Routines from SDL_audio.h }
function SdlAudioDriverName (NameBuf: TString; Len: Integer): TString;
function SdlOpenAudio (Desired, Obtained: PSdlAudioSpec): Boolean; attribute (ignorable);
procedure SdlPauseAudio (PauseOn: Integer); attribute (name = 'SDL_PauseAudio'); external;
function SdlLoadWavRW (Src: PSdlRWops; FreeSrc: Integer; Spec: PSdlAudioSpec; var AudioBuf: Pointer; var Len: CInteger): PSdlAudioSpec; attribute (name = 'SDL_LoadWAV_RW'); external;
procedure SDLFreeWAV (AudioBuf: Pointer); attribute (name = 'SDL_FreeWAV'); external;
function SdlBuildAudioCVT (Cvt: PSdlAudioCVT; SrcFormat: ShortCard; SrcChannels: ByteCard; SrcRate: CInteger; DstFormat: ShortCard; DstChannels: ByteCard; DstRate: CInteger): Boolean; attribute (ignorable);
function SdlConvertAudio (Cvt: PSdlAudioCVT): Integer; attribute (name = 'SDL_ConvertAudio'); external;
procedure SdlMixAudio (DstAudio, SrcAudio: Pointer; Len: Cardinal; Volume: Integer); attribute (name = 'SDL_MixAudio'); external;
procedure SDL_LockAudio; attribute (name = 'SDL_LockAudio'); external;
procedure SDL_UnlockAudio; attribute (name = 'SDL_UnlockAudio'); external;
procedure SDL_CloseAudio; attribute (name = 'SDL_CloseAudio'); external;


{@section Routines from SDL_cdrom.h }
{ "macros" }
function CdInDrive (Status: Integer): Boolean;
procedure FramesToMSF (FParamIn: CInteger; var MParam, SParam, FParam: CInteger); attribute (name = '_p_frames_to_msf'); external;
function MSFToFrames (MParam, SParam, FParam: CInteger): Integer; attribute (name = '_p_msf_to_frames'); external;
{ "real functions" }
function SdlCdNumDrives: Integer; attribute (name = 'SDL_CDNumDrives'); external;
function SdlCdName (Drive: Integer): TString;
function SdlCdOpen (Drive: Integer): PSdlCd; attribute (name = 'SDL_CDOpen'); external;
function SdlCdStatus (Cdrom: PSdlCd): CDStatus; attribute (name = 'SDL_CDStatus'); external;
function SdlCdPlayTracks (Cdrom: PSdlCd; StartTrack, StartFrame, NTracks, NFrames: CInteger): Boolean; attribute (ignorable);
function SdlCdPlay (Cdrom: PSdlCd; Start, Lengthh: Integer): Boolean; attribute (ignorable);
function SdlCdPause (Cdrom: PSdlCd): Boolean; attribute (ignorable);
function SdlCdResume (Cdrom: PSdlCd): Boolean; attribute (ignorable);
function SdlCdStop (Cdrom: PSdlCd): Boolean; attribute (ignorable);
function SdlCdEject (Cdrom: PSdlCd): Boolean; attribute (ignorable);
procedure SdlCdClose (Cdrom: PSdlCd); attribute (name = 'SDL_CDClose'); external;


{@section Routines from SDL_cpuinfo.h }
function SdlHasRDTSC: Boolean;
function SdlHasMMX: Boolean;
function SdlHasMMXExt: Boolean;
function SdlHas3DNow: Boolean;
function SdlHas3DNowExt: Boolean;
function SdlHasSSE: Boolean;
function SdlHasSSE2: Boolean;
function SdlHasAltiVec: Boolean;


{@section Routines from SDL_error.h }
function SdlGetError: TString;
procedure SdlClearError; attribute (name = 'SDL_ClearError'); external;
{ macro }
procedure SdlOutOfMemory; attribute (name = '_p_sdl_outofmemory'); external;
procedure SdlError (Code: SdlErrorCode); attribute (name = 'SDL_Error'); external;


{@section routines from SDL_events.h }
function SdlEventMask (x: Integer): Integer; attribute (name = '_p_sdl_eventmask'); external;
procedure SdlPumpEvents; attribute (name = 'SDL_PumpEvents'); external;
{@@ Events should be an Array of size NumEvents }
function SdlPeepEvents (Events: PSdlEvent; NumEvents: Integer;
  Action: TSdlEventAction; Mask: Cardinal): Integer; attribute (name = 'SDL_PeepEvents'); external;
function SdlPollEvent (var Event: TSdlEvent): Boolean;
function SdlWaitEvent (var Event: TSdlEvent): Boolean; attribute (ignorable);
function SdlPushEvent (Event: PSdlEvent): Boolean; attribute (ignorable);
procedure SdlSetEventFilter (Filter: TSdlEventFilter); attribute (name = 'SDL_SetEventFilter'); external;
function SdlGetEventFilter: TSdlEventFilter; attribute (name = 'SDL_GetEventFilter'); external;
function SdlEventState (aType: ByteCard; State: Integer): ByteCard;
  attribute (name = 'SDL_EventState'); external;


{@section Routines from SDL_getenv.h }
{$ifdef NEED_SDL_GETENV}
function PutEnv (s: TString): Integer; attribute (ignorable);
function SdlPutenv (s: TString): Integer; attribute (ignorable);
function GetEnv (s: TString): TString;
function SdlGetenv (s: TString): TString;
{$endif}


{@section Routines from SDL_joystick.h }
function SdlNumJoysticks: Integer; attribute (name = 'SDL_NumJoysticks'); external;
function SdlJoystickName (Index: Integer): TString;
function SdlJoystickOpen (Index: Integer): PSdlJoystick; attribute (name = 'SDL_JoystickOpen'); external;
function SdlJoystickOpened (Index: Integer): Boolean;
function SdlJoystickIndex (Stick: PSdlJoystick): Integer; attribute (name = 'SDL_JoystickIndex'); external;
function SdlJoystickNumAxes (Stick: PSdlJoystick): Integer; attribute (name = 'SDL_JoystickNumAxes'); external;
function SdlJoystickNumBalls (Stick: PSdlJoystick): Integer; attribute (name = 'SDL_JoystickNumBalls'); external;
function SdlJoystickNumHats (Stick: PSdlJoystick): Integer; attribute (name = 'SDL_JoystickNumHats'); external;
function SdlJoystickNumButtons (Stick: PSdlJoystick): Integer; attribute (name = 'SDL_JoystickNumButtons'); external;
procedure SdlJoystickUpdate; attribute (name = 'SDL_JoystickUpdate'); external;
{ SDL_QUERY, SDL_ENABLE or SDL_IGNORE }
function SdlJoystickEventState (State: Integer): Integer; attribute (name = 'SDL_JoystickEventState', ignorable); external;
function SdlJoystickGetAxis (Stick: PSdlJoystick; Axis: Integer): ShortInt; attribute (name = 'SDL_JoystickGetAxis'); external;
function SdlJoystickGetHat (Stick: PSdlJoystick; Hat: Integer): ByteCard; attribute (name = 'SDL_JoystickGetHat'); external;
function SdlJoystickGetBall (Stick: PSdlJoystick; Ball: Integer; var dx, dy: Integer): Boolean; attribute (ignorable);
function SdlJoystickGetButton (Stick: PSdlJoystick; Button: Integer): ByteCard; attribute (name = 'SDL_JoystickGetButton'); external;
procedure SdlJoystickClose (Stick: PSdlJoystick); attribute (name = 'SDL_JoystickClose'); external;


{@section Routines from SDL_keyboard.h }
type
  PKeyStateArray = ^TKeyStateArray;
  TKeyStateArray = array [0..MaxVarSize div SizeOf (ByteCard) - 1] of ByteCard;

function SdlEnableUnicode (Enable: Integer): Integer; attribute (name = 'SDL_EnableUNICODE'); external;
function SdlEnableKeyRepeat (Delay, Interval: Integer): Boolean; attribute (ignorable);
function SdlGetKeyState (var NumKeys: Integer): PKeyStateArray; attribute (name = 'SDL_GetKeyState'); external;
function SdlGetModState: TSdlMod; attribute (name = 'SDL_GetModState'); external;
procedure SdlSetModState (ModState: TSdlMod); attribute (name = 'SDL_SetModState'); external;
function SdlGetKeyname (aKey: TSdlKey): TString;


{@section Routines from SDL_mouse.h }
function SdlGetMouseState (var x, y: Integer): ByteCard; attribute (name = 'SDL_GetMouseState'); external;
function SdlGetRelativeMouseState (var x, y: Integer): ByteCard; attribute (name = 'SDL_GetRelativeMouseState'); external;
procedure SdlWarpMouse (x, y: ShortCard); attribute (name = 'SDL_WarpMouse'); external;
function SdlCreateCursor (var Data, Mask: ByteCard; Width, Height, HotX, HotY: Integer): PSdlCursor; attribute (name = 'SDL_CreateCursor'); external;
procedure SdlSetCursor (Cursor: PSdlCursor); attribute (name = 'SDL_SetCursor'); external;
function SdlGetCursor: PSdlCursor; attribute (name = 'SDL_GetCursor'); external;
procedure SdlFreeCursor (Cursor: PSdlCursor); attribute (name = 'SDL_FreeCursor'); external;
{ is true, if mouse was isplayed }
function SdlShowCursor (Toggle: Integer): Boolean;
function SdlButton (x: ByteCard): ByteCard; attribute (name = '_p_sdl_button'); external;


{@section Routines From SDL_timer.h }
function SdlGetTicks: Cardinal; attribute (name = 'SDL_GetTicks'); external;
procedure SdlDelay (ms: Cardinal); attribute (name = 'SDL_Delay'); external;
{ old API, just one timer, don't use this }
function SdlSetTimer (Interval: Cardinal; CB: TSdlTimerCallback): Integer; attribute (name = 'SDL_SetTimer'); external;
{ new timer API }
function SdlAddTimer (Interval: Cardinal; Callback: TSdlNewTimerCallback; Param: Pointer): PSdlTimerId; attribute (name = 'SDL_AddTimer'); external;
function SdlRemoveTimer (TimerId: PSdlTimerId): Boolean;


{@section Routines From SDL_thread.h }
function SdlCreateThread (fn: TSdlThreadFunction; Data: Pointer): PSdlThread; attribute (name = 'SDL_CreateThread'); external;
function SdlThreadId: Cardinal; attribute (name = 'SDL_ThreadID'); external;
function SdlGetThreadId (Thread: PSdlThread): Cardinal; attribute (name = 'SDL_GetThreadID'); external;
procedure SdlWaitThread (Thread: PSdlThread; var Status: Integer); attribute (name = 'SDL_WaitThread'); external;
procedure SdlKillThread (Thread: PSdlThread); attribute (name = 'SDL_KillThread'); external;


{@section Routines From SDL_video.h }
function SdlVideoInit (DriverName: TString; Flags: Cardinal): Integer; attribute (name = 'SDL_VideoInit'); external;
procedure SdlVideoQuit; attribute (name = 'SDL_VideoQuit'); external;
function SdlGetVideoSurface: PSdlSurface; attribute (name = 'SDL_GetVideoSurface'); external;
function SdlGetVideoInfo: PSdlVideoInfo; attribute (name = 'SDL_GetVideoInfo'); external;
function SdlVideoModeOk (Width, Height, Bpp: Integer;
  Flags: Cardinal): Integer; attribute (name = 'SDL_VideoModeOK'); external;
function SdlSetVideoMode (Width, Height, Bpp: Integer; Flags: Cardinal): PSdlSurface; attribute (name = 'SDL_SetVideoMode'); external;
procedure SdlUpdateRect (Surface: PSdlSurface; x, y: Integer; w, h: Cardinal); attribute (name = 'SDL_UpdateRect'); external;
type
  PSdlRects = ^TSdlRects;
  TSdlRects = array [0 .. MaxVarSize div SizeOf (TSdlRect) -1] of TSdlRect;
procedure SdlUpdateRects (Surface: PSdlSurface; NumRects: Integer; Rects: PSdlRects); attribute (name = 'SDL_UpdateRects'); external;
function SdlFlip (Screen: PSdlSurface): Integer; attribute (name = 'SDL_Flip'); external;
function SdlSetGamma (Red, Green, Blue: ShortReal): Integer; attribute (name = 'SDL_SetGamma'); external;
function SdlSetGammaRamp (var Red, Green, Blue: ShortCard): Integer;
  attribute (name = 'SDL_SetGammaRamp'); external;
function SdlMapRGB (Format: PSdlPixelFormat;
  r, g, b: ByteCard): Integer; attribute (name = 'SDL_MapRGB'); external;
function SdlMapRGBA (var Format: TSdlPixelFormat;
  r, g, b, a: ByteCard): Integer; attribute (name = 'SDL_MapRGBA'); external;
procedure SdlGetRGB (Pixel: Cardinal; Fmt: PSdlPixelFormat;
  var r, g, b: ByteCard); attribute (name = 'SDL_GetRGB'); external;
procedure SdlGetRGBA (Pixel: Cardinal; Fmt: PSdlPixelFormat;
  var r, g, b, a: ByteCard); attribute (name = 'SDL_GetRGBA'); external;
function SdlCreateRGBSurface (Flags: Cardinal; Width, Height, Depth: Integer;
  RMask, GMask, BMask, AMask: Cardinal): PSdlSurface;
  attribute (name = 'SDL_CreateRGBSurface'); external;
function SdlCreateRGBSurfaceFrom (Pixels: Pointer; Width, Height, Depth,
  Pitch: Integer; RMask, GMask, BMask, AMask: Cardinal): PSdlSurface;
  attribute (name = 'SDL_CreateRGBSurfaceFrom'); external;
procedure SdlFreeSurface (Surface: PSdlSurface); attribute (name = 'SDL_FreeSurface'); external;
function SdlLockSurface (Surface: PSdlSurface): Integer; attribute (name = 'SDL_LockSurface'); external;
procedure SdlUnlockSurface (Surface: PSdlSurface); attribute (name = 'SDL_UnlockSurface'); external;
function SdlSetColorKey (Surface: PSdlSurface; Flag, Key: Cardinal): Boolean; attribute (ignorable);
function SdlSetAlpha (Surface: PSdlSurface; Flag: Cardinal; Alpha: ByteCard): Integer; attribute (name = 'SDL_SetAlpha'); external;
function SdlSetClipRect (Surface: PSdlSurface; const Rect: PSdlRect): Boolean;
procedure SdlGetClipRect (Surface: PSdlSurface; var Rect: TSdlRect); attribute (name = 'SDL_GetClipRect'); external;
function SdlConvertSurface (Surface: PSdlSurface; Fmt: PSdlPixelFormat; Flags: Cardinal): PSdlSurface; attribute (name = 'SDL_ConvertSurface'); external;
function SdlBlitSurface (SrcSurface: PSdlSurface; SrcRect: PSdlRect; DestSurface: PSdlSurface; DestRect: PSdlRect): Integer; attribute (name = 'SDL_UpperBlit', ignorable); external;
function SdlUpperBlit (SrcSurface: PSdlSurface; SrcRect: PSdlRect; DestSurface: PSdlSurface; DestRect: PSdlRect): Integer; attribute (name = 'SDL_UpperBlit'); external;
function SdlLowerBlit (SrcSurface: PSdlSurface; SrcRect: PSdlRect; DestSurface: PSdlSurface; DestRect: PSdlRect): Integer; attribute (name = 'SDL_LowerBlit'); external;
function SdlFillRect (Dest: PSdlSurface; DestRect: PSdlRect; Color: Cardinal): Boolean; attribute (ignorable);
function SdlDisplayFormat (Surface: PSdlSurface): PSdlSurface; attribute (name = 'SDL_DisplayFormat'); external;
function SdlDisplayFormatAlpha (Surface: PSdlSurface): PSdlSurface; attribute (name = 'SDL_DisplayFormatAlpha'); external;
procedure SdlWMSetCaption (TitleName, IconName: TString);
procedure SDLWMGetCaption (var TitleName, IconName: TString);
procedure SDLWMSetIcon (Surface: PSdlSurface; Mask: PByteCard); attribute (name = 'SDL_WM_SetIcon'); external;
function SdlWMIconifyWindow: Integer; attribute (name = 'SDL_WM_IconifyWindow'); external;
function SDLWMToggleFullScreen (Surface: PSdlSurface): Integer; attribute (name = 'SDL_WM_ToggleFullScreen'); external;
function SDLWMGrabInput (Mode: TSdlGrabMode): TSdlGrabMode; attribute (name = 'SDL_WM_GrabInput'); external;
function SdlMustlock (Surface: PSdlSurface): Boolean;
function SdlLoadBmp (const FileName: TString): PSdlSurface;
function SdlSaveBmp (Surface: PSdlSurface; const FileName: TString): Boolean; attribute (ignorable);



implementation

{$L sdlc.c}
{$L SDL}
{$L pthread}

{ Audio }
function CSdlAudioDriverName (NameBuf: CString; Len: CInteger): CString; attribute (name = 'SDL_AudioDriverName'); external;
function SdlAudioDriverName (NameBuf: TString; Len: Integer): TString;
begin
  SdlAudioDriverName := CString2String (CSdlAudioDriverName (NameBuf, Len))
end;

function CSdlOpenAudio (Desired, Obtained: PSdlAudioSpec): CInteger; attribute (name = 'SDL_OpenAudio'); external;
function SdlOpenAudio (Desired, Obtained: PSdlAudioSpec): Boolean;
begin
  SdlOpenAudio := CSdlOpenAudio (Desired, Obtained) = 0
end;

function CSdlBuildAudioCVT (Cvt: PSdlAudioCVT; SrcFormat: ShortCard; SrcChannels: ByteCard; SrcRate: CInteger; DstFormat: ShortCard; DstChannels: ByteCard; DstRate: CInteger): CInteger; attribute (name = 'SDL_BuildAudioCVT'); external;
function SdlBuildAudioCVT (Cvt: PSdlAudioCVT; SrcFormat: ShortCard; SrcChannels: ByteCard; SrcRate: CInteger; DstFormat: ShortCard; DstChannels: ByteCard; DstRate: CInteger): Boolean;
begin
  SdlBuildAudioCVT := CSdlBuildAudioCVT (Cvt, SrcFormat, SrcChannels, SrcRate, DstFormat, DstChannels, DstRate) = 0
end;


{ Cdrom }
function CCdInDrive (Status: CInteger): CInteger; attribute (name = '_p_cd_indrive'); external;
function CdInDrive (Status: Integer): Boolean;
begin
  CdInDrive := CCdInDrive (Status) <> 0
end;

function CSdlCDName (Drive: CInteger): CString; attribute (name = 'SDL_CDName'); external;
function SdlCdName (Drive: Integer): TString;
begin
  SdlCdName := CString2String (CSdlCDName (Drive))
end;

function CSdlCDPlayTracks (Cdrom: PSdlCd; StartTrack, StartFrame, NTracks, NFrames: CInteger): CInteger; attribute (name = 'SDL_CDPlayTracks'); external;
function SdlCdPlayTracks (Cdrom: PSdlCd; StartTrack, StartFrame, NTracks, NFrames: CInteger): Boolean;
begin
  SdlCdPlayTracks := CSdlCDPlayTracks (Cdrom, StartTrack, StartFrame, NTracks, NFrames) = 0
end;

function CSdlCDPlay (Cdrom: PSdlCd; Start, Lengthh: CInteger): CInteger; attribute (name = 'SDL_CDPlay'); external;
function SdlCdPlay (Cdrom: PSdlCd; Start, Lengthh: Integer): Boolean;
begin
  SdlCdPlay := CSdlCDPlay (Cdrom, Start, Lengthh) = 0
end;

function CSdlCDPause (Cdrom: PSdlCd): CInteger; attribute (name = 'SDL_CDPause'); external;
function SdlCdPause (Cdrom: PSdlCd): Boolean;
begin
  SdlCdPause := CSdlCDPause (Cdrom) = 0
end;

function CSdlCDResume (Cdrom: PSdlCd): CInteger; attribute (name = 'SDL_CDResume'); external;
function SdlCdResume (Cdrom: PSdlCd): Boolean;
begin
  SdlCdResume := CSdlCDResume (Cdrom) = 0
end;

function CSdlCDStop (Cdrom: PSdlCd): CInteger; attribute (name = 'SDL_CDStop'); external;
function SdlCdStop (Cdrom: PSdlCd): Boolean;
begin
  SdlCdStop := CSdlCDStop (Cdrom) = 0
end;

function CSdlCDEject (Cdrom: PSdlCd): CInteger; attribute (name = 'SDL_CDEject'); external;
function SdlCdEject (Cdrom: PSdlCd): Boolean;
begin
  SdlCdEject := CSdlCDEject (Cdrom) = 0
end;

{ cpuinfo }

function CSdlHasRDTSC: CInteger; attribute (name = 'SDL_HasRDTSC'); external;
function SdlHasRDTSC: Boolean;
begin
  SdlHasRDTSC := CSdlHasRDTSC <> 0
end;

function CSdlHasMMX: CInteger; attribute (name = 'SDL_HasMMX'); external;
function SdlHasMMX: Boolean;
begin
  SdlHasMMX := CSdlHasMMX <> 0
end;

function CSdlHasMMXExt: CInteger; attribute (name = 'SDL_HasMMXExt'); external;
function SdlHasMMXExt: Boolean;
begin
  SdlHasMMXExt := CSdlHasMMXExt <> 0
end;

function CSdlHas3DNow: CInteger; attribute (name = 'SDL_Has3DNow'); external;
function SdlHas3DNow: Boolean;
begin
  SdlHas3DNow := CSdlHas3DNow <> 0
end;

function CSdlHas3DNowExt: CInteger; attribute (name = 'SDL_Has3DNowExt'); external;
function SdlHas3DNowExt: Boolean;
begin
  SdlHas3DNowExt := CSdlHas3DNowExt <> 0
end;

function CSdlHasSSE: CInteger; attribute (name = 'SDL_HasSSE'); external;
function SdlHasSSE: Boolean;
begin
  SdlHasSSE := CSdlHasSSE <> 0
end;

function CSdlHasSSE2: CInteger; attribute (name = 'SDL_HasSSE2'); external;
function SdlHasSSE2: Boolean;
begin
  SdlHasSSE2 := CSdlHasSSE2 <> 0
end;

function CSdlHasAltiVec: CInteger; attribute (name = 'SDL_HasAltiVec'); external;
function SdlHasAltiVec: Boolean;
begin
  SdlHasAltiVec := CSdlHasAltiVec <> 0
end;



function CSdlGetError: PChar; attribute (name = 'SDL_GetError'); external;
function SdlGetError: TString;
begin
  SdlGetError := CString2String (CSdlGetError)
end;

function CSdlPollEvent (var Event: TSdlEvent): Integer; attribute (name = 'SDL_PollEvent'); external;
function SdlPollEvent (var Event: TSdlEvent): Boolean;
var
  r: Integer;
begin
  r := CSdlPollEvent (Event);
  SdlPollEvent := (r = 1)  
end;

function CSdlWaitEvent (var Event: TSdlEvent): Integer; attribute (name = 'SDL_WaitEvent'); external;
function SdlWaitEvent (var Event: TSdlEvent): Boolean;
begin
  SdlWaitEvent := CSdlWaitEvent (Event) <> 0
end;

function CSdlPushEvent (Event: PSdlEvent): CInteger; attribute (name = 'SDL_PushEvent'); external;
function SdlPushEvent (Event: PSdlEvent): Boolean;
begin
  SdlPushEvent := CSdlPushEvent (Event) = 0
end;


{ SDL_getenv.h }
{$ifdef NEED_SDL_GETENV}
function CPutEnv (s: CString): CInteger; attribute (name = '_p_putenv'); external;
function PutEnv (s: TString): Integer;
begin
  PutEnv := CPutEnv (s)
end;

function CSdlPutenv (s: CString): CInteger; attribute (name = 'SDL_putenv'); external;
function SdlPutenv (s: TString): Integer;
begin
  SdlPutenv := CSdlPutenv (s)
end;

function CGetEnv (s: CString): CString; attribute (name = '_p_getenv'); external;
function GetEnv (s: TString): TString;
begin
  GetEnv := CString2String (CGetEnv (s))
end;

function CSdlGetenv (s: CString): CString; attribute (name = 'SDL_getenv'); external;
function SdlGetenv (s: TString): TString;
begin
  SdlGetenv := CString2String (CSdlGetenv (s))
end;
{$endif}


{ joystick }
function CSdlJoystickName (Index: Integer): CString; attribute (name = 'SDL_JoystickName'); external;
function SdlJoystickName (Index: Integer): TString;
begin
  SdlJoystickName := CString2String (CSdlJoystickName (Index))
end;

function CSdlJoystickOpened (Index: Integer): CInteger; attribute (name = 'SDL_JoystickOpened'); external;
function SdlJoystickOpened (Index: Integer): Boolean;
begin
  SdlJoystickOpened := CSdlJoystickOpened (Index) = 1
end;

function CSdlJoystickGetBall (Stick: PSdlJoystick; Ball: Integer; var dx, dy: CInteger): CInteger; attribute (name = 'SDL_JoystickGetBall'); external;
function SdlJoystickGetBall (Stick: PSdlJoystick; Ball: Integer; var dx, dy: Integer): Boolean;
var
  x, y: CInteger;
  Ret: Boolean;
begin
  x := dx;
  y := dy;
  Ret := CSdlJoystickGetBall (Stick, Ball, x, y) = 0;
  dx := x;
  dy := y;
  SdlJoystickGetBall := Ret
end;


{ mouse }
function CSdlShowCursor (Toggle: Integer): Integer; attribute (name = 'SDL_ShowCursor'); external;
function SdlShowCursor (Toggle: Integer): Boolean;
begin
  SdlShowCursor := CSdlShowCursor (Toggle) = 1 
end;



function CSdlRemoveTimer (TimerId: PSdlTimerId): Integer; attribute (name = 'SDL_RemoveTimer'); external;
function SdlRemoveTimer (TimerId: PSdlTimerId): Boolean;
begin
  SdlRemoveTimer := (CSdlRemoveTimer (TimerId) = 1)
end;

function CSdlEnableKeyRepeat (Delay, Interval: Integer): CInteger; attribute (name = 'SDL_EnableKeyRepeat'); external;
function SdlEnableKeyRepeat (Delay, Interval: Integer): Boolean;
begin
  SdlEnableKeyRepeat := CSdlEnableKeyRepeat (Delay, Interval) = 0
end;

function CSdlGetKeyname (aKey: TSdlKey): PChar; attribute (name = 'SDL_GetKeyName'); external;
function SdlGetKeyname (aKey: TSdlKey): TString;
begin
  SdlGetKeyname := CString2String (CSdlGetKeyname (aKey))
end;

function CSdlSetColorKey (Surface: PSdlSurface; Flag, Key: Cardinal): CInteger; attribute (name = 'SDL_SetColorKey'); external;
function SdlSetColorKey (Surface: PSdlSurface; Flag, Key: Cardinal): Boolean;
begin
  SdlSetColorKey := CSdlSetColorKey (Surface, Flag, Key) = 0
end;

function CSdlSetClipRect (Surface: PSdlSurface; const Rect: PSdlRect): Integer;
attribute (name = 'SDL_SetClipRect'); external;
function SdlSetClipRect (Surface: PSdlSurface; const Rect: PSdlRect): Boolean;
begin
  SdlSetClipRect := (CSdlSetClipRect (Surface, Rect) = 1)
end;

procedure CSdlWMSetCaption (TitleName, IconName: PChar);
attribute (name = 'SDL_WM_SetCaption'); external;
procedure SdlWMSetCaption (TitleName, IconName: TString);
begin
  CSdlWMSetCaption (
    String2CString (TitleName),
    String2CString (IconName))
end;

function CSdlFillRect (Dest: PSdlSurface; DestRect: PSdlRect; Color: Cardinal): Integer; attribute (name = 'SDL_FillRect'); external;
function SdlFillRect (Dest: PSdlSurface; DestRect: PSdlRect; Color: Cardinal): Boolean;
begin
  SdlFillRect := CSdlFillRect (Dest, DestRect, Color) = 0
end;


procedure CSDLWMGetCaption (var TitleName, IconName: PChar); attribute (name = 'SDL_WM_GetCaption'); external;
procedure SDLWMGetCaption (var TitleName, IconName: TString);
var
  t, i: PChar;
begin
  CSDLWMGetCaption (t, i);
  TitleName := CString2String (t);
  IconName := CString2String (i)
end;

function CSdlMustlock (Surface: PSdlSurface): Integer;
attribute (name = '_p_sdl_mustlock'); external;
function SdlMustlock (Surface: PSdlSurface): Boolean;
begin
  SdlMustlock := (CSdlMustlock (Surface) = 1)
end;

function CSdlLoadBmp (const FileName: CString): PSdlSurface; attribute (name = '_p_sdl_loadbmp'); external;
function SdlLoadBmp (const FileName: TString): PSdlSurface;
begin
  SdlLoadBmp := CSdlLoadBmp (String2CString (FileName))
end;


function CSdlSaveBmp (Surface: PSdlSurface; const FileName: CString): CInteger; attribute (name = '_p_sdl_savebmp'); external;
function SdlSaveBmp (Surface: PSdlSurface; const FileName: TString): Boolean;
begin
  SdlSaveBmp := CSdlSaveBmp (Surface, String2CString (FileName)) = 0
end;


function CSizeofSdlKey: Integer; attribute (name = '_p_sizeof_SDLKey'); external;
function PSizeofSdlKey: Integer;
begin
  PSizeofSdlKey := SizeOf (TSdlKey)
end;

function CSizeofSdlMod: Integer; attribute (name = '_p_sizeof_SDLMod'); external;
function PSizeofSdlMod: Integer;
begin
  PSizeofSdlMod := SizeOf (TSdlMod)
end;

function CSizeofSdlKeysym: Integer; attribute (name = '_p_sizeof_SDL_keysym'); external;
function PSizeofSdlKeysym: Integer;
begin
  PSizeofSdlKeysym := SizeOf (TSdlKeysym)
end;

function CSizeofSdlActiveEvent: Integer; attribute (name = '_p_sizeof_SDL_ActiveEvent'); external;
function PSizeofSdlActiveEvent: Integer;
begin
  PSizeofSdlActiveEvent := SizeOf (TSdlActiveEvent)
end;

function CSizeofSdlKeyboardEvent: Integer; attribute (name = '_p_sizeof_SDL_KeyboardEvent'); external;
function PSizeofSdlKeyboardEvent: Integer;
begin
  PSizeofSdlKeyboardEvent := SizeOf (TSdlKeyboardEvent)
end;

function CSizeofSdlMouseMotionEvent: Integer; attribute (name = '_p_sizeof_SDL_MouseMotionEvent'); external;
function PSizeofSdlMouseMotionEvent: Integer;
begin
  PSizeofSdlMouseMotionEvent := SizeOf (TSdlMouseMotionEvent)
end;

function CSizeofSdlMouseButtonEvent: Integer; attribute (name = '_p_sizeof_SDL_MouseButtonEvent'); external;
function PSizeofSdlMouseButtonEvent: Integer;
begin
  PSizeofSdlMouseButtonEvent := SizeOf (TSdlMouseButtonEvent)
end;

function CSizeofSdlJoyAxisEvent: Integer; attribute (name = '_p_sizeof_SDL_JoyAxisEvent'); external;
function PSizeofSdlJoyAxisEvent: Integer;
begin
  PSizeofSdlJoyAxisEvent := SizeOf (TSdlJoyAxisEvent)
end;

function CSizeofSdlJoyBallEvent: Integer; attribute (name = '_p_sizeof_SDL_JoyBallEvent'); external;
function PSizeofSdlJoyBallEvent: Integer;
begin
  PSizeofSdlJoyBallEvent := SizeOf (TSdlJoyBallEvent)
end;

function CSizeofSdlJoyHatEvent: Integer; attribute (name = '_p_sizeof_SDL_JoyHatEvent'); external;
function PSizeofSdlJoyHatEvent: Integer;
begin
  PSizeofSdlJoyHatEvent := SizeOf (TSdlJoyHatEvent)
end;

function CSizeofSdlJoyButtonEvent: Integer; attribute (name = '_p_sizeof_SDL_JoyButtonEvent'); external;
function PSizeofSdlJoyButtonEvent: Integer;
begin
  PSizeofSdlJoyButtonEvent := SizeOf (TSdlJoyButtonEvent)
end;

function CSizeofSdlResizeEvent: Integer; attribute (name = '_p_sizeof_SDL_ResizeEvent'); external;
function PSizeofSdlResizeEvent: Integer;
begin
  PSizeofSdlResizeEvent := SizeOf (TSdlResizeEvent)
end;

function CSizeofSdlExposeEvent: Integer; attribute (name = '_p_sizeof_SDL_ExposeEvent'); external;
function PSizeofSdlExposeEvent: Integer;
begin
  PSizeofSdlExposeEvent := SizeOf (TSdlExposeEvent)
end;

function CSizeofSdlQuitEvent: Integer; attribute (name = '_p_sizeof_SDL_QuitEvent'); external;
function PSizeofSdlQuitEvent: Integer;
begin
  PSizeofSdlQuitEvent := SizeOf (TSdlQuitEvent)
end;

function CSizeofSdlUserEvent: Integer; attribute (name = '_p_sizeof_SDL_UserEvent'); external;
function PSizeofSdlUserEvent: Integer;
begin
  PSizeofSdlUserEvent := SizeOf (TSdlUserEvent)
end;

function CSizeofSdlSysWMEvent: Integer; attribute (name = '_p_sizeof_SDL_SysWMEvent'); external;
function PSizeofSdlSysWMEvent: Integer;
begin
  PSizeofSdlSysWMEvent := SizeOf (TSdlSysWMEvent)
end;

function CSizeofSdlEvent: Integer; attribute (name = '_p_sizeof_SDL_Event'); external;
function PSizeofSdlEvent: Integer;
begin
  PSizeofSdlEvent := SizeOf (TSdlEvent)
end;

function CSizeofSdlEventAction: Integer; attribute (name = '_p_sizeof_SDL_eventaction'); external;
function PSizeofSdlEventAction: Integer;
begin
  PSizeofSdlEventAction := SizeOf (TSdlEventAction)
end;

function CSizeofSdlRect: Integer; attribute (name = '_p_sizeof_sdl_Rect'); external;
function PSizeofSdlRect: Integer;
begin
  PSizeofSdlRect := SizeOf (TSdlRect)
end;

function CSizeofSdlColor: Integer; attribute (name = '_p_sizeof_sdl_Color'); external;
function PSizeofSdlColor: Integer;
begin
  PSizeofSdlColor := SizeOf (TSdlColor)
end;

function CSizeofSdlPalette: Integer; attribute (name = '_p_sizeof_sdl_Palette'); external;
function PSizeofSdlPalette: Integer;
begin
  PSizeofSdlPalette := SizeOf (TSdlPalette)
end;

function CSizeofSdlPixelFormat: Integer; attribute (name = '_p_sizeof_sdl_PixelFormat'); external;
function PSizeofSdlPixelFormat: Integer;
begin
  PSizeofSdlPixelFormat := SizeOf (TSdlPixelFormat)
end;

function CSizeofSdlSurface: Integer; attribute (name = '_p_sizeof_sdl_Surface'); external;
function PSizeofSdlSurface: Integer;
begin
  PSizeofSdlSurface := SizeOf (TSdlSurface)
end;

function CSizeofSdlVideoInfo: Integer; attribute (name = '_p_sizeof_sdl_VideoInfo'); external;
function PSizeofSdlVideoInfo: Integer;
begin
  PSizeofSdlVideoInfo := SizeOf (TSdlVideoInfo)
end;

function CSizeofSdlOverlay: Integer; attribute (name = '_p_sizeof_sdl_Overlay'); external;
function PSizeofSdlOverlay: Integer;
begin
  PSizeofSdlOverlay := SizeOf (TSdlOverlay)
end;

function CSizeofSdlGLattr: Integer; attribute (name = '_p_sizeof_sdl_GLattr'); external;
function PSizeofSdlGLattr: Integer;
begin
  PSizeofSdlGLattr := SizeOf (TSdlGLattr)
end;

function CSizeofSdlGrabMode: Integer; attribute (name = '_p_sizeof_sdl_GrabMode'); external;
function PSizeofSdlGrabMode: Integer;
begin
  PSizeofSdlGrabMode := SizeOf (TSdlGrabMode)
end;


to begin do
  begin
  if CSizeofSdlKey <> PSizeofSdlKey then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlKey');
      Halt
    end;
  if CSizeofSdlMod <> PSizeofSdlMod then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlMod');
      Halt
    end;
  if CSizeofSdlKeysym <> PSizeofSdlKeysym then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlKeysym');
      Halt
    end;
  if CSizeofSdlActiveEvent <> PSizeofSdlActiveEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlActiveEvent');
      Halt
    end;
  if CSizeofSdlKeyboardEvent <> PSizeofSdlKeyboardEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlKeyboardEvent');
      Halt
    end;
  if CSizeofSdlMouseMotionEvent <> PSizeofSdlMouseMotionEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlMouseMotionEvent');
      Halt
    end;
  if CSizeofSdlMouseButtonEvent <> PSizeofSdlMouseButtonEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlMouseButtonEvent');
      Halt
    end;
  if CSizeofSdlJoyAxisEvent <> PSizeofSdlJoyAxisEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlJoyAxisEvent');
      Halt
    end;
  if CSizeofSdlJoyBallEvent <> PSizeofSdlJoyBallEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlJoyBallEvent');
      Halt
    end;
  if CSizeofSdlJoyHatEvent <> PSizeofSdlJoyHatEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlJoyHatEvent');
      Halt
    end;
  if CSizeofSdlJoyButtonEvent <> PSizeofSdlJoyButtonEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlJoyButtonEvent');
      Halt
    end;
  if CSizeofSdlResizeEvent <> PSizeofSdlResizeEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlResizeEvent');
      Halt
    end;
  if CSizeofSdlExposeEvent <> PSizeofSdlExposeEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlExposeEvent ');
      Halt
    end;
  if CSizeofSdlQuitEvent <> PSizeofSdlQuitEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlQuitEvent ');
      Halt
    end;
  if CSizeofSdlUserEvent <> PSizeofSdlUserEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlUserEvent ');
      Halt
    end;
  if CSizeofSdlSysWMEvent <> PSizeofSdlSysWMEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlSysWMEvent ');
      Halt
    end;
  if CSizeofSdlEvent <> PSizeofSdlEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlEvent ');
      Halt
    end;
  if CSizeofSdlEventAction <> PSizeofSdlEventAction then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlEventAction');
      Halt
    end;
  if CSizeofSdlRect <> PSizeofSdlRect then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlRect');
      Halt
    end;
  if CSizeofSdlColor <> PSizeofSdlColor then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlColor');
      Halt
    end;
  if CSizeofSdlPalette <> PSizeofSdlPalette then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlPalette');
      Halt
    end;
  if CSizeofSdlPixelFormat <> PSizeofSdlPixelFormat then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlPixelFormat');
      Halt
    end;
  if CSizeofSdlSurface <> PSizeofSdlSurface then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlSurface');
      Halt
    end;
  if CSizeofSdlVideoInfo <> PSizeofSdlVideoInfo then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlVideoInfo');
      Halt
    end;
  if CSizeofSdlOverlay <> PSizeofSdlOverlay then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlOverlay');
      Halt
    end;
  if CSizeofSdlGLattr <> PSizeofSdlGLattr then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlGLattr');
      Halt
    end;
  if CSizeofSdlGrabMode <> PSizeofSdlGrabMode then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlGrabMode');
      Halt
    end;

  end;

end.

