/*  GNU Pascal Interface to SDL. 
    Copyright (C) 2005 by Eike Lange
    
    This unit is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This unit is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Eike Lange, eike.lange@uni-essen.de
    http://www.gnu-pascal.de/~contrib/eike/

New: SDL_audio.h, SDL_byteorder.h, SDL_cdrom.h, SDL_error.h,
  SDL_getenv.h, SDL_joystick.h, SDL_mutex.h, SDL_syswm.h

Notes:
  SDL/SDL_syswm.h is included in this file

Missing:
  SDL_audio.h: defined functions
  SDL_endian.h: coming soon
  SDL_loadso.h: Not for Pascal!
  SDL_main.h: Someone with Macintosh experiences should have a look if this is needful.
  SDKL_name.h: Nothing to implement
  SDL_opengl.h: really missing :-(  coming soon 
  SDL_rwops.h: just file seek/set functions
  SDL_version.h: macros
*/


#include <SDL/SDL.h>


/* From SDL.h */
const int _p_sdl_init_timer       = SDL_INIT_TIMER;
const int _p_sdl_init_audio       = SDL_INIT_AUDIO;
const int _p_sdl_init_video       = SDL_INIT_VIDEO;
const int _p_sdl_init_cdrom       = SDL_INIT_CDROM;
const int _p_sdl_init_joystick    = SDL_INIT_JOYSTICK;
const int _p_sdl_init_noparachute = SDL_INIT_NOPARACHUTE;
const int _p_sdl_init_eventthread = SDL_INIT_EVENTTHREAD;
const int _p_sdl_init_everything  = SDL_INIT_EVERYTHING;


/* From SDL_active.h */
const int _p_sdl_appmousefocus    = SDL_APPMOUSEFOCUS;
const int _p_sdl_appinputfocus    = SDL_APPINPUTFOCUS;
const int _p_sdl_appactive        = SDL_APPACTIVE;


/** From SDL_audio.h */
const int _p_AUDIO_U8     = AUDIO_U8;
const int _p_AUDIO_S8     = AUDIO_S8;
const int _p_AUDIO_U16LSB = AUDIO_U16LSB;
const int _p_AUDIO_S16LSB = AUDIO_S16LSB;
const int _p_AUDIO_U16MSB = AUDIO_U16MSB;
const int _p_AUDIO_S16MSB = AUDIO_S16MSB;
const int _p_AUDIO_U16    = AUDIO_U16;
const int _p_AUDIO_S16    = AUDIO_S16;
const int _p_AUDIO_U16SYS = AUDIO_U16SYS;
const int _p_AUDIO_S16SYS = AUDIO_S16SYS;
const int _p_sdl_MIX_MAXVOLUME = SDL_MIX_MAXVOLUME;
/* enum SDL_audiostatus */
const int _p_sdl_AUDIO_STOPPED  = SDL_AUDIO_STOPPED;
const int _p_sdl_AUDIO_PLAYING  = SDL_AUDIO_PLAYING;
const int _p_sdl_AUDIO_PAUSED   = SDL_AUDIO_PAUSED;


/** From SDL_byteorder.h */
const int _p_sdl_LIL_ENDIAN = SDL_LIL_ENDIAN;
const int _p_sdl_BIG_ENDIAN = SDL_BIG_ENDIAN;


/** From SDL_cdrom.h */
const int _p_sdl_MAX_TRACKS = SDL_MAX_TRACKS;
const int _p_sdl_AUDIO_TRACK = SDL_AUDIO_TRACK;
const int _p_sdl_DATA_TRACK = SDL_DATA_TRACK;
const int _p_cd_FPS = CD_FPS;

/* Typedef CDstatus */
const int _p_cd_TRAYEMPTY = CD_TRAYEMPTY;
const int _p_cd_STOPPED = CD_STOPPED;
const int _p_cd_PLAYING = CD_PLAYING;
const int _p_cd_PAUSED = CD_PAUSED;
const int _p_cd_ERROR = CD_ERROR;
          
int _p_cd_indrive (int status)
{
  return (int) CD_INDRIVE(status);
}

void _p_frames_to_msf (int f, int *M, int *S, int *F)
{
  FRAMES_TO_MSF(f, M,S,F);
}
int _p_msf_to_frames (int M, int S, int F)
{
  return MSF_TO_FRAMES (M, S, F);
}            


/** From SDL_error.h */
void _p_sdl_outofmemory (void)
{
  SDL_OutOfMemory();
}
/* enum SDL_errorcode */
const int _p_sdl_ENOMEM = SDL_ENOMEM;
const int _p_sdl_EFREAD = SDL_EFREAD;
const int _p_sdl_EFWRITE = SDL_EFWRITE;
const int _p_sdl_EFSEEK = SDL_EFSEEK;
const int _p_sdl_LASTERROR = SDL_LASTERROR;


/* From SDL_event.h */
int _p_sizeof_SDL_ActiveEvent (void) { return sizeof (SDL_ActiveEvent); }
int _p_sizeof_SDL_KeyboardEvent (void) { return sizeof (SDL_KeyboardEvent); }
int _p_sizeof_SDL_MouseMotionEvent (void) { return sizeof (SDL_MouseMotionEvent); }
int _p_sizeof_SDL_MouseButtonEvent (void) { return sizeof (SDL_MouseButtonEvent); }
int _p_sizeof_SDL_JoyAxisEvent (void) { return sizeof (SDL_JoyAxisEvent ); }
int _p_sizeof_SDL_JoyBallEvent (void) { return sizeof (SDL_JoyBallEvent); }
int _p_sizeof_SDL_JoyHatEvent (void) { return sizeof (SDL_JoyHatEvent); }
int _p_sizeof_SDL_JoyButtonEvent (void) { return sizeof (SDL_JoyButtonEvent); }
int _p_sizeof_SDL_ResizeEvent (void) { return sizeof (SDL_ResizeEvent); }
int _p_sizeof_SDL_ExposeEvent (void) { return sizeof (SDL_ExposeEvent); }
int _p_sizeof_SDL_QuitEvent (void) { return sizeof (SDL_QuitEvent); }
int _p_sizeof_SDL_UserEvent (void) { return sizeof (SDL_UserEvent); }
int _p_sizeof_SDL_SysWMEvent (void) { return sizeof (SDL_SysWMEvent); }
int _p_sizeof_SDL_Event (void) { return sizeof (SDL_Event); }
int _p_sizeof_SDL_eventaction (void) { return sizeof (SDL_eventaction); }

int _p_sdl_eventmask (int X) { return (SDL_EVENTMASK (X)); }

/* Enum SDL_Events */
const int _p_sdl_NOEVENT      = SDL_NOEVENT;
const int _p_sdl_ACTIVEEVENT  = SDL_ACTIVEEVENT;
const int _p_sdl_KEYDOWN      = SDL_KEYDOWN;
const int _p_sdl_KEYUP        = SDL_KEYUP;
const int _p_sdl_MOUSEMOTION  = SDL_MOUSEMOTION;
const int _p_sdl_MOUSEBUTTONDOWN  = SDL_MOUSEBUTTONDOWN;
const int _p_sdl_MOUSEBUTTONUP  = SDL_MOUSEBUTTONUP;
const int _p_sdl_JOYAXISMOTION  = SDL_JOYAXISMOTION;
const int _p_sdl_JOYBALLMOTION  = SDL_JOYBALLMOTION;
const int _p_sdl_JOYHATMOTION   = SDL_JOYHATMOTION;
const int _p_sdl_JOYBUTTONDOWN  = SDL_JOYBUTTONDOWN;
const int _p_sdl_JOYBUTTONUP    = SDL_JOYBUTTONUP;
const int _p_sdl_QUIT           = SDL_QUIT;
const int _p_sdl_SYSWMEVENT     = SDL_SYSWMEVENT;
const int _p_sdl_EVENT_RESERVEDA  = SDL_EVENT_RESERVEDA;
const int _p_sdl_EVENT_RESERVEDB  = SDL_EVENT_RESERVEDB;
const int _p_sdl_VIDEORESIZE    = SDL_VIDEORESIZE;
const int _p_sdl_VIDEOEXPOSE    = SDL_VIDEOEXPOSE;
const int _p_sdl_EVENT_RESERVED2  = SDL_EVENT_RESERVED2;
const int _p_sdl_EVENT_RESERVED3  = SDL_EVENT_RESERVED3;
const int _p_sdl_EVENT_RESERVED4  = SDL_EVENT_RESERVED4;
const int _p_sdl_EVENT_RESERVED5  = SDL_EVENT_RESERVED5;
const int _p_sdl_EVENT_RESERVED6  = SDL_EVENT_RESERVED6;
const int _p_sdl_EVENT_RESERVED7  = SDL_EVENT_RESERVED7;
const int _p_sdl_USEREVENT  = SDL_USEREVENT;
const int _p_sdl_NUMEVENTS  = SDL_NUMEVENTS;
const int _p_sdl_ACTIVEEVENTMASK      = SDL_ACTIVEEVENTMASK;
const int _p_sdl_KEYDOWNMASK          = SDL_KEYDOWNMASK;
const int _p_sdl_KEYUPMASK            = SDL_KEYUPMASK;
const int _p_sdl_MOUSEMOTIONMASK      = SDL_MOUSEMOTIONMASK;
const int _p_sdl_MOUSEBUTTONDOWNMASK  = SDL_MOUSEBUTTONDOWNMASK;
const int _p_sdl_MOUSEBUTTONUPMASK    = SDL_MOUSEBUTTONUPMASK;
const int _p_sdl_MOUSEEVENTMASK       = SDL_MOUSEEVENTMASK;
const int _p_sdl_JOYAXISMOTIONMASK    = SDL_JOYAXISMOTIONMASK;
const int _p_sdl_JOYBALLMOTIONMASK    = SDL_JOYBALLMOTIONMASK;
const int _p_sdl_JOYHATMOTIONMASK     = SDL_JOYHATMOTIONMASK;
const int _p_sdl_JOYBUTTONDOWNMASK    = SDL_JOYBUTTONDOWNMASK;
const int _p_sdl_JOYBUTTONUPMASK      = SDL_JOYBUTTONUPMASK;
const int _p_sdl_JOYEVENTMASK         = SDL_JOYEVENTMASK;
const int _p_sdl_VIDEORESIZEMASK      = SDL_VIDEORESIZEMASK;
const int _p_sdl_VIDEOEXPOSEMASK      = SDL_VIDEOEXPOSEMASK;
const int _p_sdl_QUITMASK             = SDL_QUITMASK;
const int _p_sdl_SYSWMEVENTMASK       = SDL_SYSWMEVENTMASK;
const int _p_sdl_ALLEVENTS            = SDL_ALLEVENTS;
const int _p_sdl_query    = SDL_QUERY;
const int _p_sdl_ignore   = SDL_IGNORE;
const int _p_sdl_disable  = SDL_DISABLE;
const int _p_sdl_enable   = SDL_ENABLE;

const int _p_sdl_addevent   = SDL_ADDEVENT;
const int _p_sdl_peekevent  = SDL_PEEKEVENT;
const int _p_sdl_getevent   = SDL_GETEVENT;


/** From SDL_getenv.h */
#ifdef NEED_SDL_GETENV
int _p_putenv (const char *s)
{
  return putenv(s)
}
char* _p_getenv (const char *s)
{
  return getenv(s)
}
#endif

/** From SDL_joystick.h */
const int _p_sdl_HAT_CENTERED = SDL_HAT_CENTERED;
const int _p_sdl_HAT_UP = SDL_HAT_UP;
const int _p_sdl_HAT_RIGHT = SDL_HAT_RIGHT;
const int _p_sdl_HAT_DOWN = SDL_HAT_DOWN;
const int _p_sdl_HAT_LEFT = SDL_HAT_LEFT;
const int _p_sdl_HAT_RIGHTUP = SDL_HAT_RIGHTUP;
const int _p_sdl_HAT_RIGHTDOWN = SDL_HAT_RIGHTDOWN;
const int _p_sdl_HAT_LEFTUP = SDL_HAT_LEFTUP;
const int _p_sdl_HAT_LEFTDOWN = SDL_HAT_LEFTDOWN;


/* From SDL_keyboard.h */
int _p_sizeof_SDL_keysym (void) { return sizeof (SDL_keysym); }

const int _p_sdl_all_hotkeys = SDL_ALL_HOTKEYS;
const int _p_sdl_default_repeat_delay = SDL_DEFAULT_REPEAT_DELAY;
const int _p_sdl_default_repeat_interval = SDL_DEFAULT_REPEAT_INTERVAL;

/* From SDL_keysym.h */
int _p_sizeof_SDLKey (void) { return sizeof (SDLKey); }
int _p_sizeof_SDLMod (void) { return sizeof (SDLMod); }

const int _p_sdlk_UNKNOWN  = SDLK_UNKNOWN;
const int _p_sdlk_FIRST  = SDLK_FIRST;
const int _p_sdlk_BACKSPACE  = SDLK_BACKSPACE;
const int _p_sdlk_TAB  = SDLK_TAB;
const int _p_sdlk_CLEAR  = SDLK_CLEAR;
const int _p_sdlk_RETURN  = SDLK_RETURN;
const int _p_sdlk_PAUSE  = SDLK_PAUSE;
const int _p_sdlk_ESCAPE  = SDLK_ESCAPE;
const int _p_sdlk_SPACE  = SDLK_SPACE;
const int _p_sdlk_EXCLAIM  = SDLK_EXCLAIM;
const int _p_sdlk_QUOTEDBL  = SDLK_QUOTEDBL;
const int _p_sdlk_HASH  = SDLK_HASH;
const int _p_sdlk_DOLLAR  = SDLK_DOLLAR;
const int _p_sdlk_AMPERSAND  = SDLK_AMPERSAND;
const int _p_sdlk_QUOTE  = SDLK_QUOTE;
const int _p_sdlk_LEFTPAREN  = SDLK_LEFTPAREN;
const int _p_sdlk_RIGHTPAREN  = SDLK_RIGHTPAREN;
const int _p_sdlk_ASTERISK  = SDLK_ASTERISK;
const int _p_sdlk_PLUS  = SDLK_PLUS;
const int _p_sdlk_COMMA  = SDLK_COMMA;
const int _p_sdlk_MINUS  = SDLK_MINUS;
const int _p_sdlk_PERIOD  = SDLK_PERIOD;
const int _p_sdlk_SLASH  = SDLK_SLASH;
const int _p_sdlk_0  = SDLK_0;
const int _p_sdlk_1  = SDLK_1;
const int _p_sdlk_2  = SDLK_2;
const int _p_sdlk_3  = SDLK_3;
const int _p_sdlk_4  = SDLK_4;
const int _p_sdlk_5  = SDLK_5;
const int _p_sdlk_6  = SDLK_6;
const int _p_sdlk_7  = SDLK_7;
const int _p_sdlk_8  = SDLK_8;
const int _p_sdlk_9  = SDLK_9;
const int _p_sdlk_COLON  = SDLK_COLON;
const int _p_sdlk_SEMICOLON  = SDLK_SEMICOLON;
const int _p_sdlk_LESS  = SDLK_LESS;
const int _p_sdlk_EQUALS  = SDLK_EQUALS;
const int _p_sdlk_GREATER  = SDLK_GREATER;
const int _p_sdlk_QUESTION  = SDLK_QUESTION;
const int _p_sdlk_AT  = SDLK_AT;
const int _p_sdlk_LEFTBRACKET = SDLK_LEFTBRACKET;
const int _p_sdlk_BACKSLASH  = SDLK_BACKSLASH;
const int _p_sdlk_RIGHTBRACKET = SDLK_RIGHTBRACKET;
const int _p_sdlk_CARET  = SDLK_CARET;
const int _p_sdlk_UNDERSCORE  = SDLK_UNDERSCORE;
const int _p_sdlk_BACKQUOTE  = SDLK_BACKQUOTE;
const int _p_sdlk_a  = SDLK_a;
const int _p_sdlk_b  = SDLK_b;
const int _p_sdlk_c  = SDLK_c;
const int _p_sdlk_d  = SDLK_d;
const int _p_sdlk_e  = SDLK_e;
const int _p_sdlk_f  = SDLK_f;
const int _p_sdlk_g  = SDLK_g;
const int _p_sdlk_h  = SDLK_h;
const int _p_sdlk_i  = SDLK_i;
const int _p_sdlk_j  = SDLK_j;
const int _p_sdlk_k  = SDLK_k;
const int _p_sdlk_l  = SDLK_l;
const int _p_sdlk_m  = SDLK_m;
const int _p_sdlk_n  = SDLK_n;
const int _p_sdlk_o  = SDLK_o;
const int _p_sdlk_p  = SDLK_p;
const int _p_sdlk_q  = SDLK_q;
const int _p_sdlk_r  = SDLK_r;
const int _p_sdlk_s  = SDLK_s;
const int _p_sdlk_t  = SDLK_t;
const int _p_sdlk_u  = SDLK_u;
const int _p_sdlk_v  = SDLK_v;
const int _p_sdlk_w  = SDLK_w;
const int _p_sdlk_x  = SDLK_x;
const int _p_sdlk_y  = SDLK_y;
const int _p_sdlk_z  = SDLK_z;
const int _p_sdlk_DELETE  = SDLK_DELETE;
const int _p_sdlk_WORLD_0  = SDLK_WORLD_0;
const int _p_sdlk_WORLD_1  = SDLK_WORLD_1;
const int _p_sdlk_WORLD_2  = SDLK_WORLD_2;
const int _p_sdlk_WORLD_3  = SDLK_WORLD_3;
const int _p_sdlk_WORLD_4  = SDLK_WORLD_4;
const int _p_sdlk_WORLD_5  = SDLK_WORLD_5;
const int _p_sdlk_WORLD_6  = SDLK_WORLD_6;
const int _p_sdlk_WORLD_7  = SDLK_WORLD_7;
const int _p_sdlk_WORLD_8  = SDLK_WORLD_8;
const int _p_sdlk_WORLD_9  = SDLK_WORLD_9;
const int _p_sdlk_WORLD_10  = SDLK_WORLD_10;
const int _p_sdlk_WORLD_11  = SDLK_WORLD_11;
const int _p_sdlk_WORLD_12  = SDLK_WORLD_12;
const int _p_sdlk_WORLD_13  = SDLK_WORLD_13;
const int _p_sdlk_WORLD_14  = SDLK_WORLD_14;
const int _p_sdlk_WORLD_15  = SDLK_WORLD_15;
const int _p_sdlk_WORLD_16  = SDLK_WORLD_16;
const int _p_sdlk_WORLD_17  = SDLK_WORLD_17;
const int _p_sdlk_WORLD_18  = SDLK_WORLD_18;
const int _p_sdlk_WORLD_19  = SDLK_WORLD_19;
const int _p_sdlk_WORLD_20  = SDLK_WORLD_20;
const int _p_sdlk_WORLD_21  = SDLK_WORLD_21;
const int _p_sdlk_WORLD_22  = SDLK_WORLD_22;
const int _p_sdlk_WORLD_23  = SDLK_WORLD_23;
const int _p_sdlk_WORLD_24  = SDLK_WORLD_24;
const int _p_sdlk_WORLD_25  = SDLK_WORLD_25;
const int _p_sdlk_WORLD_26  = SDLK_WORLD_26;
const int _p_sdlk_WORLD_27  = SDLK_WORLD_27;
const int _p_sdlk_WORLD_28  = SDLK_WORLD_28;
const int _p_sdlk_WORLD_29  = SDLK_WORLD_29;
const int _p_sdlk_WORLD_30  = SDLK_WORLD_30;
const int _p_sdlk_WORLD_31  = SDLK_WORLD_31;
const int _p_sdlk_WORLD_32  = SDLK_WORLD_32;
const int _p_sdlk_WORLD_33  = SDLK_WORLD_33;
const int _p_sdlk_WORLD_34  = SDLK_WORLD_34;
const int _p_sdlk_WORLD_35  = SDLK_WORLD_35;
const int _p_sdlk_WORLD_36  = SDLK_WORLD_36;
const int _p_sdlk_WORLD_37  = SDLK_WORLD_37;
const int _p_sdlk_WORLD_38  = SDLK_WORLD_38;
const int _p_sdlk_WORLD_39  = SDLK_WORLD_39;
const int _p_sdlk_WORLD_40  = SDLK_WORLD_40;
const int _p_sdlk_WORLD_41  = SDLK_WORLD_41;
const int _p_sdlk_WORLD_42  = SDLK_WORLD_42;
const int _p_sdlk_WORLD_43  = SDLK_WORLD_43;
const int _p_sdlk_WORLD_44  = SDLK_WORLD_44;
const int _p_sdlk_WORLD_45  = SDLK_WORLD_45;
const int _p_sdlk_WORLD_46  = SDLK_WORLD_46;
const int _p_sdlk_WORLD_47  = SDLK_WORLD_47;
const int _p_sdlk_WORLD_48  = SDLK_WORLD_48;
const int _p_sdlk_WORLD_49  = SDLK_WORLD_49;
const int _p_sdlk_WORLD_50  = SDLK_WORLD_50;
const int _p_sdlk_WORLD_51  = SDLK_WORLD_51;
const int _p_sdlk_WORLD_52  = SDLK_WORLD_52;
const int _p_sdlk_WORLD_53  = SDLK_WORLD_53;
const int _p_sdlk_WORLD_54  = SDLK_WORLD_54;
const int _p_sdlk_WORLD_55  = SDLK_WORLD_55;
const int _p_sdlk_WORLD_56  = SDLK_WORLD_56;
const int _p_sdlk_WORLD_57  = SDLK_WORLD_57;
const int _p_sdlk_WORLD_58  = SDLK_WORLD_58;
const int _p_sdlk_WORLD_59  = SDLK_WORLD_59;
const int _p_sdlk_WORLD_60  = SDLK_WORLD_60;
const int _p_sdlk_WORLD_61  = SDLK_WORLD_61;
const int _p_sdlk_WORLD_62  = SDLK_WORLD_62;
const int _p_sdlk_WORLD_63  = SDLK_WORLD_63;
const int _p_sdlk_WORLD_64  = SDLK_WORLD_64;
const int _p_sdlk_WORLD_65  = SDLK_WORLD_65;
const int _p_sdlk_WORLD_66  = SDLK_WORLD_66;
const int _p_sdlk_WORLD_67  = SDLK_WORLD_67;
const int _p_sdlk_WORLD_68  = SDLK_WORLD_68;
const int _p_sdlk_WORLD_69  = SDLK_WORLD_69;
const int _p_sdlk_WORLD_70  = SDLK_WORLD_70;
const int _p_sdlk_WORLD_71  = SDLK_WORLD_71;
const int _p_sdlk_WORLD_72  = SDLK_WORLD_72;
const int _p_sdlk_WORLD_73  = SDLK_WORLD_73;
const int _p_sdlk_WORLD_74  = SDLK_WORLD_74;
const int _p_sdlk_WORLD_75  = SDLK_WORLD_75;
const int _p_sdlk_WORLD_76  = SDLK_WORLD_76;
const int _p_sdlk_WORLD_77  = SDLK_WORLD_77;
const int _p_sdlk_WORLD_78  = SDLK_WORLD_78;
const int _p_sdlk_WORLD_79  = SDLK_WORLD_79;
const int _p_sdlk_WORLD_80  = SDLK_WORLD_80;
const int _p_sdlk_WORLD_81  = SDLK_WORLD_81;
const int _p_sdlk_WORLD_82  = SDLK_WORLD_82;
const int _p_sdlk_WORLD_83  = SDLK_WORLD_83;
const int _p_sdlk_WORLD_84  = SDLK_WORLD_84;
const int _p_sdlk_WORLD_85  = SDLK_WORLD_85;
const int _p_sdlk_WORLD_86  = SDLK_WORLD_86;
const int _p_sdlk_WORLD_87  = SDLK_WORLD_87;
const int _p_sdlk_WORLD_88  = SDLK_WORLD_88;
const int _p_sdlk_WORLD_89  = SDLK_WORLD_89;
const int _p_sdlk_WORLD_90  = SDLK_WORLD_90;
const int _p_sdlk_WORLD_91  = SDLK_WORLD_91;
const int _p_sdlk_WORLD_92  = SDLK_WORLD_92;
const int _p_sdlk_WORLD_93  = SDLK_WORLD_93;
const int _p_sdlk_WORLD_94  = SDLK_WORLD_94;
const int _p_sdlk_WORLD_95  = SDLK_WORLD_95;
const int _p_sdlk_KP0  = SDLK_KP0;
const int _p_sdlk_KP1  = SDLK_KP1;
const int _p_sdlk_KP2  = SDLK_KP2;
const int _p_sdlk_KP3  = SDLK_KP3;
const int _p_sdlk_KP4  = SDLK_KP4;
const int _p_sdlk_KP5  = SDLK_KP5;
const int _p_sdlk_KP6  = SDLK_KP6;
const int _p_sdlk_KP7  = SDLK_KP7;
const int _p_sdlk_KP8  = SDLK_KP8;
const int _p_sdlk_KP9  = SDLK_KP9;
const int _p_sdlk_KP_PERIOD  = SDLK_KP_PERIOD;
const int _p_sdlk_KP_DIVIDE  = SDLK_KP_DIVIDE;
const int _p_sdlk_KP_MULTIPLY	= SDLK_KP_MULTIPLY;
const int _p_sdlk_KP_MINUS  = SDLK_KP_MINUS;
const int _p_sdlk_KP_PLUS  = SDLK_KP_PLUS;
const int _p_sdlk_KP_ENTER  = SDLK_KP_ENTER;
const int _p_sdlk_KP_EQUALS  = SDLK_KP_EQUALS;
const int _p_sdlk_UP  = SDLK_UP;
const int _p_sdlk_DOWN  = SDLK_DOWN;
const int _p_sdlk_RIGHT  = SDLK_RIGHT;
const int _p_sdlk_LEFT  = SDLK_LEFT;
const int _p_sdlk_INSERT  = SDLK_INSERT;
const int _p_sdlk_HOME  = SDLK_HOME;
const int _p_sdlk_END  = SDLK_END;
const int _p_sdlk_PAGEUP  = SDLK_PAGEUP;
const int _p_sdlk_PAGEDOWN  = SDLK_PAGEDOWN;
const int _p_sdlk_F1  = SDLK_F1;
const int _p_sdlk_F2  = SDLK_F2;
const int _p_sdlk_F3  = SDLK_F3;
const int _p_sdlk_F4  = SDLK_F4;
const int _p_sdlk_F5  = SDLK_F5;
const int _p_sdlk_F6  = SDLK_F6;
const int _p_sdlk_F7  = SDLK_F7;
const int _p_sdlk_F8  = SDLK_F8;
const int _p_sdlk_F9  = SDLK_F9;
const int _p_sdlk_F10  = SDLK_F10;
const int _p_sdlk_F11  = SDLK_F11;
const int _p_sdlk_F12  = SDLK_F12;
const int _p_sdlk_F13  = SDLK_F13;
const int _p_sdlk_F14  = SDLK_F14;
const int _p_sdlk_F15  = SDLK_F15;
const int _p_sdlk_NUMLOCK  = SDLK_NUMLOCK;
const int _p_sdlk_CAPSLOCK  = SDLK_CAPSLOCK;
const int _p_sdlk_SCROLLOCK  = SDLK_SCROLLOCK;
const int _p_sdlk_RSHIFT  = SDLK_RSHIFT;
const int _p_sdlk_LSHIFT  = SDLK_LSHIFT;
const int _p_sdlk_RCTRL  = SDLK_RCTRL;
const int _p_sdlk_LCTRL  = SDLK_LCTRL;
const int _p_sdlk_RALT  = SDLK_RALT;
const int _p_sdlk_LALT  = SDLK_LALT;
const int _p_sdlk_RMETA  = SDLK_RMETA;
const int _p_sdlk_LMETA  = SDLK_LMETA;
const int _p_sdlk_LSUPER  = SDLK_LSUPER;
const int _p_sdlk_RSUPER  = SDLK_RSUPER;
const int _p_sdlk_MODE  = SDLK_MODE;
const int _p_sdlk_COMPOSE  = SDLK_COMPOSE;
const int _p_sdlk_HELP  = SDLK_HELP;
const int _p_sdlk_PRINT  = SDLK_PRINT;
const int _p_sdlk_SYSREQ  = SDLK_SYSREQ;
const int _p_sdlk_BREAK  = SDLK_BREAK;
const int _p_sdlk_MENU  = SDLK_MENU;
const int _p_sdlk_POWER  = SDLK_POWER;
const int _p_sdlk_EURO  = SDLK_EURO;
const int _p_sdlk_UNDO  = SDLK_UNDO;
const int _p_sdlk_LAST  = SDLK_LAST;

const int _p_kmod_NONE   = KMOD_NONE;
const int _p_kmod_LSHIFT = KMOD_LSHIFT;
const int _p_kmod_RSHIFT = KMOD_RSHIFT;
const int _p_kmod_LCTRL  = KMOD_LCTRL;
const int _p_kmod_RCTRL  = KMOD_RCTRL;
const int _p_kmod_LALT   = KMOD_LALT;
const int _p_kmod_RALT   = KMOD_RALT;
const int _p_kmod_LMETA  = KMOD_LMETA;
const int _p_kmod_RMETA  = KMOD_RMETA;
const int _p_kmod_NUM    = KMOD_NUM;
const int _p_kmod_CAPS   = KMOD_CAPS;
const int _p_kmod_MODE   = KMOD_MODE;
const int _p_kmod_RESERVED = KMOD_RESERVED;
const int _p_kmod_CTRL  = KMOD_CTRL;
const int _p_kmod_SHIFT = KMOD_SHIFT;
const int _p_kmod_ALT   = KMOD_ALT;
const int _p_kmod_META  = KMOD_META;


/* From SDL_mouse.h */
const int _p_sdl_button_left    = SDL_BUTTON_LEFT;
const int _p_sdl_button_middle  = SDL_BUTTON_MIDDLE;
const int _p_sdl_button_right   = SDL_BUTTON_RIGHT;
const int _p_sdl_BUTTON_WHEELUP = SDL_BUTTON_WHEELUP;
const int _p_sdl_BUTTON_WHEELDOWN = SDL_BUTTON_WHEELDOWN;
const int _p_sdl_button_lmask   = SDL_BUTTON_LMASK;
const int _p_sdl_button_mmask   = SDL_BUTTON_MMASK;
const int _p_sdl_button_rmask   = SDL_BUTTON_RMASK;
Uint8 _p_sdl_button (Uint8 X)
{
  return (SDL_BUTTON(X));
}


/** From SDL_mutex.h */
const int _p_sdl_MUTEX_TIMEDOUT = SDL_MUTEX_TIMEDOUT;
const int _p_sdl_MUTEX_MAXWAIT = SDL_MUTEX_MAXWAIT;
int _p_SDL_LockMutex (SDL_mutex *m) { return SDL_LockMutex (m); }
int _p_SDL_UnlockMutex (SDL_mutex *m) { return SDL_UnlockMutex (m); }


/** From SDL_syswm.h */
/* enum SDL_SYSWM_TYPE */
#include <SDL/SDL_syswm.h>
const int _p_sdl_SYSWM_X11 = SDL_SYSWM_X11;


/* From SDL_timer.h */
const int _p_sdl_timeslice = SDL_TIMESLICE;
const int _p_timer_resolution = TIMER_RESOLUTION;


/* From SDL_types.h */
/* SDL_bool is just boolean, Uint32, Sint8, ... are mapped to the
types of GPC. */
const int _p_sdl_pressed          = SDL_PRESSED;
const int _p_sdl_released         = SDL_RELEASED;


/* From SDL_version.h */
const int _p_sdl_major_version    = SDL_MAJOR_VERSION;
const int _p_sdl_minor_version    = SDL_MINOR_VERSION;
const int _p_sdl_patchlevel       = SDL_PATCHLEVEL;


/* From SDL_video.h */
int _p_sizeof_sdl_Rect (void)         { return sizeof (SDL_Rect); }
int _p_sizeof_sdl_Color (void)        { return sizeof (SDL_Color); }
int _p_sizeof_sdl_Palette (void)      { return sizeof (SDL_Palette); }
int _p_sizeof_sdl_PixelFormat (void)  { return sizeof (SDL_PixelFormat); }
int _p_sizeof_sdl_Surface (void)      { return sizeof (SDL_Surface); }
int _p_sizeof_sdl_VideoInfo (void)    { return sizeof (SDL_VideoInfo); }
int _p_sizeof_sdl_Overlay (void)      { return sizeof (SDL_Overlay); }
int _p_sizeof_sdl_GLattr (void)       { return sizeof (SDL_GLattr); }
int _p_sizeof_sdl_GrabMode (void)     { return sizeof (SDL_GrabMode); }

int _p_sdl_mustlock (SDL_Surface *sf) { return (SDL_MUSTLOCK (sf)); }
SDL_Surface *_p_sdl_loadbmp (const char *filename) { return SDL_LoadBMP (filename); }
int _p_sdl_savebmp (SDL_Surface *surface, const char *filename) { return SDL_SaveBMP (surface, filename); }

const int _p_sdl_ALPHA_OPAQUE = SDL_ALPHA_OPAQUE;
const int _p_sdl_ALPHA_TRANSPARENT = SDL_ALPHA_TRANSPARENT;
const int _p_sdl_SWSURFACE = SDL_SWSURFACE;
const int _p_sdl_HWSURFACE = SDL_HWSURFACE;
const int _p_sdl_ASYNCBLIT = SDL_ASYNCBLIT;
const int _p_sdl_ANYFORMAT = SDL_ANYFORMAT;
const int _p_sdl_HWPALETTE = SDL_HWPALETTE;
const int _p_sdl_DOUBLEBUF = SDL_DOUBLEBUF;
const int _p_sdl_FULLSCREEN = SDL_FULLSCREEN;
const int _p_sdl_OPENGL = SDL_OPENGL;
const int _p_sdl_OPENGLBLIT = SDL_OPENGLBLIT;
const int _p_sdl_RESIZABLE = SDL_RESIZABLE;
const int _p_sdl_NOFRAME = SDL_NOFRAME;
const int _p_sdl_HWACCEL = SDL_HWACCEL;
const int _p_sdl_SRCCOLORKEY = SDL_SRCCOLORKEY;
const int _p_sdl_RLEACCELOK = SDL_RLEACCELOK;
const int _p_sdl_RLEACCEL = SDL_RLEACCEL;
const int _p_sdl_SRCALPHA = SDL_SRCALPHA;
const int _p_sdl_PREALLOC = SDL_PREALLOC;

const int _p_sdl_YV12_OVERLAY = SDL_YV12_OVERLAY;
const int _p_sdl_IYUV_OVERLAY = SDL_IYUV_OVERLAY;
const int _p_sdl_YUY2_OVERLAY = SDL_YUY2_OVERLAY;
const int _p_sdl_UYVY_OVERLAY = SDL_UYVY_OVERLAY;
const int _p_sdl_YVYU_OVERLAY = SDL_YVYU_OVERLAY;

const int _p_sdl_LOGPAL   = SDL_LOGPAL;
const int _p_sdl_PHYSPAL  = SDL_PHYSPAL;
/* enum SDL_GLattr */
const int _p_sdl_gl_RED_SIZE          = SDL_GL_RED_SIZE;
const int _p_sdl_gl_GREEN_SIZE        = SDL_GL_GREEN_SIZE;
const int _p_sdl_gl_BLUE_SIZE         = SDL_GL_BLUE_SIZE;
const int _p_sdl_gl_ALPHA_SIZE        = SDL_GL_ALPHA_SIZE;
const int _p_sdl_gl_BUFFER_SIZE       = SDL_GL_BUFFER_SIZE;
const int _p_sdl_gl_DOUBLEBUFFER      = SDL_GL_DOUBLEBUFFER;
const int _p_sdl_gl_DEPTH_SIZE        = SDL_GL_DEPTH_SIZE;
const int _p_sdl_gl_STENCIL_SIZE      = SDL_GL_STENCIL_SIZE;
const int _p_sdl_gl_ACCUM_RED_SIZE    = SDL_GL_ACCUM_RED_SIZE;
const int _p_sdl_gl_ACCUM_GREEN_SIZE  = SDL_GL_ACCUM_GREEN_SIZE;
const int _p_sdl_gl_ACCUM_BLUE_SIZE   = SDL_GL_ACCUM_BLUE_SIZE;
const int _p_sdl_gl_ACCUM_ALPHA_SIZE  = SDL_GL_ACCUM_ALPHA_SIZE;
const int _p_sdl_GL_STEREO            = SDL_GL_STEREO;
const int _p_sdl_GL_MULTISAMPLEBUFFERS = SDL_GL_MULTISAMPLEBUFFERS;
const int _p_sdl_GL_MULTISAMPLESAMPLES = SDL_GL_MULTISAMPLESAMPLES;

const int _p_sdl_grab_query       = SDL_GRAB_QUERY;
const int _p_sdl_grab_off         = SDL_GRAB_OFF;
const int _p_sdl_grab_on          = SDL_GRAB_ON;
const int _p_sdl_grab_fullscreen  = SDL_GRAB_FULLSCREEN;

